# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "AWS Lake Formation"
prefix = "lakeformation"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


AddLFTagsToResource = Action("AddLFTagsToResource")
BatchGrantPermissions = Action("BatchGrantPermissions")
BatchRevokePermissions = Action("BatchRevokePermissions")
CancelTransaction = Action("CancelTransaction")
CommitTransaction = Action("CommitTransaction")
CreateDataCellsFilter = Action("CreateDataCellsFilter")
CreateLFTag = Action("CreateLFTag")
DeleteDataCellsFilter = Action("DeleteDataCellsFilter")
DeleteLFTag = Action("DeleteLFTag")
DeleteObjectsOnCancel = Action("DeleteObjectsOnCancel")
DeregisterResource = Action("DeregisterResource")
DescribeResource = Action("DescribeResource")
DescribeTransaction = Action("DescribeTransaction")
ExtendTransaction = Action("ExtendTransaction")
GetDataAccess = Action("GetDataAccess")
GetDataLakeSettings = Action("GetDataLakeSettings")
GetEffectivePermissionsForPath = Action("GetEffectivePermissionsForPath")
GetLFTag = Action("GetLFTag")
GetQueryState = Action("GetQueryState")
GetQueryStatistics = Action("GetQueryStatistics")
GetResourceLFTags = Action("GetResourceLFTags")
GetTableObjects = Action("GetTableObjects")
GetWorkUnitResults = Action("GetWorkUnitResults")
GetWorkUnits = Action("GetWorkUnits")
GrantPermissions = Action("GrantPermissions")
ListDataCellsFilter = Action("ListDataCellsFilter")
ListLFTags = Action("ListLFTags")
ListPermissions = Action("ListPermissions")
ListResources = Action("ListResources")
ListTableStorageOptimizers = Action("ListTableStorageOptimizers")
ListTransactions = Action("ListTransactions")
PutDataLakeSettings = Action("PutDataLakeSettings")
RegisterResource = Action("RegisterResource")
RemoveLFTagsFromResource = Action("RemoveLFTagsFromResource")
RevokePermissions = Action("RevokePermissions")
SearchDatabasesByLFTags = Action("SearchDatabasesByLFTags")
SearchTablesByLFTags = Action("SearchTablesByLFTags")
StartQueryPlanning = Action("StartQueryPlanning")
StartTransaction = Action("StartTransaction")
UpdateLFTag = Action("UpdateLFTag")
UpdateResource = Action("UpdateResource")
UpdateTableObjects = Action("UpdateTableObjects")
UpdateTableStorageOptimizer = Action("UpdateTableStorageOptimizer")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "AWS Security Hub"
prefix = "securityhub"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


AcceptAdministratorInvitation = Action("AcceptAdministratorInvitation")
AcceptInvitation = Action("AcceptInvitation")
BatchDisableStandards = Action("BatchDisableStandards")
BatchEnableStandards = Action("BatchEnableStandards")
BatchGetStandardsControlAssociations = Action("BatchGetStandardsControlAssociations")
BatchImportFindings = Action("BatchImportFindings")
BatchUpdateFindings = Action("BatchUpdateFindings")
BatchUpdateStandardsControlAssociations = Action(
    "BatchUpdateStandardsControlAssociations"
)
CreateActionTarget = Action("CreateActionTarget")
CreateFindingAggregator = Action("CreateFindingAggregator")
CreateInsight = Action("CreateInsight")
CreateMembers = Action("CreateMembers")
DeclineInvitations = Action("DeclineInvitations")
DeleteActionTarget = Action("DeleteActionTarget")
DeleteFindingAggregator = Action("DeleteFindingAggregator")
DeleteInsight = Action("DeleteInsight")
DeleteInvitations = Action("DeleteInvitations")
DeleteMembers = Action("DeleteMembers")
DescribeActionTargets = Action("DescribeActionTargets")
DescribeHub = Action("DescribeHub")
DescribeOrganizationConfiguration = Action("DescribeOrganizationConfiguration")
DescribeProducts = Action("DescribeProducts")
DescribeStandards = Action("DescribeStandards")
DescribeStandardsControls = Action("DescribeStandardsControls")
DisableImportFindingsForProduct = Action("DisableImportFindingsForProduct")
DisableOrganizationAdminAccount = Action("DisableOrganizationAdminAccount")
DisableSecurityHub = Action("DisableSecurityHub")
DisassociateFromAdministratorAccount = Action("DisassociateFromAdministratorAccount")
DisassociateFromMasterAccount = Action("DisassociateFromMasterAccount")
DisassociateMembers = Action("DisassociateMembers")
EnableImportFindingsForProduct = Action("EnableImportFindingsForProduct")
EnableOrganizationAdminAccount = Action("EnableOrganizationAdminAccount")
EnableSecurityHub = Action("EnableSecurityHub")
GetAdhocInsightResults = Action("GetAdhocInsightResults")
GetAdministratorAccount = Action("GetAdministratorAccount")
GetControlFindingSummary = Action("GetControlFindingSummary")
GetEnabledStandards = Action("GetEnabledStandards")
GetFindingAggregator = Action("GetFindingAggregator")
GetFindings = Action("GetFindings")
GetFreeTrialEndDate = Action("GetFreeTrialEndDate")
GetFreeTrialUsage = Action("GetFreeTrialUsage")
GetInsightFindingTrend = Action("GetInsightFindingTrend")
GetInsightResults = Action("GetInsightResults")
GetInsights = Action("GetInsights")
GetInvitationsCount = Action("GetInvitationsCount")
GetMasterAccount = Action("GetMasterAccount")
GetMembers = Action("GetMembers")
GetUsage = Action("GetUsage")
InviteMembers = Action("InviteMembers")
ListControlEvaluationSummaries = Action("ListControlEvaluationSummaries")
ListEnabledProductsForImport = Action("ListEnabledProductsForImport")
ListFindingAggregators = Action("ListFindingAggregators")
ListInvitations = Action("ListInvitations")
ListMembers = Action("ListMembers")
ListOrganizationAdminAccounts = Action("ListOrganizationAdminAccounts")
ListProductSubscribers = Action("ListProductSubscribers")
ListSecurityControlDefinitions = Action("ListSecurityControlDefinitions")
ListTagsForResource = Action("ListTagsForResource")
SendFindingEvents = Action("SendFindingEvents")
SendInsightEvents = Action("SendInsightEvents")
TagResource = Action("TagResource")
UntagResource = Action("UntagResource")
UpdateActionTarget = Action("UpdateActionTarget")
UpdateFindingAggregator = Action("UpdateFindingAggregator")
UpdateFindings = Action("UpdateFindings")
UpdateInsight = Action("UpdateInsight")
UpdateOrganizationConfiguration = Action("UpdateOrganizationConfiguration")
UpdateSecurityHubConfiguration = Action("UpdateSecurityHubConfiguration")
UpdateStandardsControl = Action("UpdateStandardsControl")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "Amazon WorkDocs"
prefix = "workdocs"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


AbortDocumentVersionUpload = Action("AbortDocumentVersionUpload")
ActivateUser = Action("ActivateUser")
AddResourcePermissions = Action("AddResourcePermissions")
AddUserToGroup = Action("AddUserToGroup")
CheckAlias = Action("CheckAlias")
CreateComment = Action("CreateComment")
CreateCustomMetadata = Action("CreateCustomMetadata")
CreateFolder = Action("CreateFolder")
CreateInstance = Action("CreateInstance")
CreateLabels = Action("CreateLabels")
CreateNotificationSubscription = Action("CreateNotificationSubscription")
CreateUser = Action("CreateUser")
DeactivateUser = Action("DeactivateUser")
DeleteComment = Action("DeleteComment")
DeleteCustomMetadata = Action("DeleteCustomMetadata")
DeleteDocument = Action("DeleteDocument")
DeleteFolder = Action("DeleteFolder")
DeleteFolderContents = Action("DeleteFolderContents")
DeleteInstance = Action("DeleteInstance")
DeleteLabels = Action("DeleteLabels")
DeleteNotificationSubscription = Action("DeleteNotificationSubscription")
DeleteUser = Action("DeleteUser")
DeregisterDirectory = Action("DeregisterDirectory")
DescribeActivities = Action("DescribeActivities")
DescribeAvailableDirectories = Action("DescribeAvailableDirectories")
DescribeComments = Action("DescribeComments")
DescribeDocumentVersions = Action("DescribeDocumentVersions")
DescribeFolderContents = Action("DescribeFolderContents")
DescribeGroups = Action("DescribeGroups")
DescribeInstances = Action("DescribeInstances")
DescribeNotificationSubscriptions = Action("DescribeNotificationSubscriptions")
DescribeResourcePermissions = Action("DescribeResourcePermissions")
DescribeRootFolders = Action("DescribeRootFolders")
DescribeUsers = Action("DescribeUsers")
DownloadDocumentVersion = Action("DownloadDocumentVersion")
GetCurrentUser = Action("GetCurrentUser")
GetDocument = Action("GetDocument")
GetDocumentPath = Action("GetDocumentPath")
GetDocumentVersion = Action("GetDocumentVersion")
GetFolder = Action("GetFolder")
GetFolderPath = Action("GetFolderPath")
GetGroup = Action("GetGroup")
GetResources = Action("GetResources")
InitiateDocumentVersionUpload = Action("InitiateDocumentVersionUpload")
RegisterDirectory = Action("RegisterDirectory")
RemoveAllResourcePermissions = Action("RemoveAllResourcePermissions")
RemoveResourcePermission = Action("RemoveResourcePermission")
RemoveUserFromGroup = Action("RemoveUserFromGroup")
UpdateDocument = Action("UpdateDocument")
UpdateDocumentVersion = Action("UpdateDocumentVersion")
UpdateFolder = Action("UpdateFolder")
UpdateInstanceAlias = Action("UpdateInstanceAlias")
UpdateUser = Action("UpdateUser")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "Amazon Macie Classic"
prefix = "macie"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


AcceptInvitation = Action("AcceptInvitation")
ArchiveFindings = Action("ArchiveFindings")
AssociateMemberAccount = Action("AssociateMemberAccount")
AssociateS3Resources = Action("AssociateS3Resources")
BatchGetCustomDataIdentifiers = Action("BatchGetCustomDataIdentifiers")
CreateClassificationJob = Action("CreateClassificationJob")
CreateCustomDataIdentifier = Action("CreateCustomDataIdentifier")
CreateFindingsFilter = Action("CreateFindingsFilter")
CreateInvitations = Action("CreateInvitations")
CreateMember = Action("CreateMember")
CreateSampleFindings = Action("CreateSampleFindings")
DeclineInvitations = Action("DeclineInvitations")
DeleteCustomDataIdentifier = Action("DeleteCustomDataIdentifier")
DeleteFindingsFilter = Action("DeleteFindingsFilter")
DeleteInvitations = Action("DeleteInvitations")
DeleteMember = Action("DeleteMember")
DescribeBuckets = Action("DescribeBuckets")
DescribeClassificationJob = Action("DescribeClassificationJob")
DescribeOrganizationConfiguration = Action("DescribeOrganizationConfiguration")
DisableMacie = Action("DisableMacie")
DisableOrganizationAdminAccount = Action("DisableOrganizationAdminAccount")
DisassociateFromMasterAccount = Action("DisassociateFromMasterAccount")
DisassociateMember = Action("DisassociateMember")
DisassociateMemberAccount = Action("DisassociateMemberAccount")
DisassociateS3Resources = Action("DisassociateS3Resources")
EnableMacie = Action("EnableMacie")
EnableOrganizationAdminAccount = Action("EnableOrganizationAdminAccount")
GetBucketStatistics = Action("GetBucketStatistics")
GetClassificationExportConfiguration = Action("GetClassificationExportConfiguration")
GetCustomDataIdentifier = Action("GetCustomDataIdentifier")
GetFindingStatistics = Action("GetFindingStatistics")
GetFindings = Action("GetFindings")
GetFindingsFilter = Action("GetFindingsFilter")
GetInvitationsCount = Action("GetInvitationsCount")
GetMacieSession = Action("GetMacieSession")
GetMasterAccount = Action("GetMasterAccount")
GetMember = Action("GetMember")
GetUsageStatistics = Action("GetUsageStatistics")
GetUsageTotals = Action("GetUsageTotals")
ListClassificationJobs = Action("ListClassificationJobs")
ListCustomDataIdentifiers = Action("ListCustomDataIdentifiers")
ListFindings = Action("ListFindings")
ListFindingsFilters = Action("ListFindingsFilters")
ListInvitations = Action("ListInvitations")
ListMemberAccounts = Action("ListMemberAccounts")
ListMembers = Action("ListMembers")
ListOrganizationAdminAccounts = Action("ListOrganizationAdminAccounts")
ListS3Resources = Action("ListS3Resources")
ListTagsForResources = Action("ListTagsForResources")
PutClassificationExportConfiguration = Action("PutClassificationExportConfiguration")
TagResource = Action("TagResource")
TestCustomDataIdentifier = Action("TestCustomDataIdentifier")
UnarchiveFindings = Action("UnarchiveFindings")
UntagResource = Action("UntagResource")
UpdateClassificationJob = Action("UpdateClassificationJob")
UpdateFindingsFilter = Action("UpdateFindingsFilter")
UpdateMemberSession = Action("UpdateMemberSession")
UpdateOrganizationConfiguration = Action("UpdateOrganizationConfiguration")
UpdateS3Resources = Action("UpdateS3Resources")
UpdateSession = Action("UpdateSession")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "AWS IoT FleetWise"
prefix = "iotfleetwise"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


AssociateVehicle = Action("AssociateVehicle")
CreateCampaign = Action("CreateCampaign")
CreateDecoderManifest = Action("CreateDecoderManifest")
CreateFleet = Action("CreateFleet")
CreateModelManifest = Action("CreateModelManifest")
CreateSignalCatalog = Action("CreateSignalCatalog")
CreateVehicle = Action("CreateVehicle")
DeleteCampaign = Action("DeleteCampaign")
DeleteDecoderManifest = Action("DeleteDecoderManifest")
DeleteFleet = Action("DeleteFleet")
DeleteModelManifest = Action("DeleteModelManifest")
DeleteSignalCatalog = Action("DeleteSignalCatalog")
DeleteVehicle = Action("DeleteVehicle")
DisassociateVehicle = Action("DisassociateVehicle")
GetCampaign = Action("GetCampaign")
GetDecoderManifest = Action("GetDecoderManifest")
GetFleet = Action("GetFleet")
GetModelManifest = Action("GetModelManifest")
GetRegisterAccountStatus = Action("GetRegisterAccountStatus")
GetSignalCatalog = Action("GetSignalCatalog")
GetVehicle = Action("GetVehicle")
GetVehicleStatus = Action("GetVehicleStatus")
ImportDecoderManifest = Action("ImportDecoderManifest")
ImportSignalCatalog = Action("ImportSignalCatalog")
ListCampaigns = Action("ListCampaigns")
ListDecoderManifestNetworkInterfaces = Action("ListDecoderManifestNetworkInterfaces")
ListDecoderManifestSignals = Action("ListDecoderManifestSignals")
ListDecoderManifests = Action("ListDecoderManifests")
ListFleets = Action("ListFleets")
ListFleetsForVehicle = Action("ListFleetsForVehicle")
ListModelManifestNodes = Action("ListModelManifestNodes")
ListModelManifests = Action("ListModelManifests")
ListSignalCatalogNodes = Action("ListSignalCatalogNodes")
ListSignalCatalogs = Action("ListSignalCatalogs")
ListVehicles = Action("ListVehicles")
ListVehiclesInFleet = Action("ListVehiclesInFleet")
RegisterAccount = Action("RegisterAccount")
UpdateCampaign = Action("UpdateCampaign")
UpdateDecoderManifest = Action("UpdateDecoderManifest")
UpdateFleet = Action("UpdateFleet")
UpdateModelManifest = Action("UpdateModelManifest")
UpdateSignalCatalog = Action("UpdateSignalCatalog")
UpdateVehicle = Action("UpdateVehicle")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "AWS CodeStar Connections"
prefix = "codestar-connections"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


CreateConnection = Action("CreateConnection")
CreateHost = Action("CreateHost")
DeleteConnection = Action("DeleteConnection")
DeleteHost = Action("DeleteHost")
GetConnection = Action("GetConnection")
GetHost = Action("GetHost")
GetIndividualAccessToken = Action("GetIndividualAccessToken")
GetInstallationUrl = Action("GetInstallationUrl")
ListConnections = Action("ListConnections")
ListHosts = Action("ListHosts")
ListInstallationTargets = Action("ListInstallationTargets")
ListTagsForResource = Action("ListTagsForResource")
PassConnection = Action("PassConnection")
RegisterAppCode = Action("RegisterAppCode")
StartAppRegistrationHandshake = Action("StartAppRegistrationHandshake")
StartOAuthHandshake = Action("StartOAuthHandshake")
TagResource = Action("TagResource")
UntagResource = Action("UntagResource")
UpdateConnectionInstallation = Action("UpdateConnectionInstallation")
UpdateHost = Action("UpdateHost")
UseConnection = Action("UseConnection")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "Amazon WorkSpaces Web"
prefix = "workspaces-web"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


AssociateBrowserSettings = Action("AssociateBrowserSettings")
AssociateNetworkSettings = Action("AssociateNetworkSettings")
AssociateTrustStore = Action("AssociateTrustStore")
AssociateUserSettings = Action("AssociateUserSettings")
CreateBrowserSettings = Action("CreateBrowserSettings")
CreateIdentityProvider = Action("CreateIdentityProvider")
CreateNetworkSettings = Action("CreateNetworkSettings")
CreatePortal = Action("CreatePortal")
CreateTrustStore = Action("CreateTrustStore")
CreateUserSettings = Action("CreateUserSettings")
DeleteBrowserSettings = Action("DeleteBrowserSettings")
DeleteIdentityProvider = Action("DeleteIdentityProvider")
DeleteNetworkSettings = Action("DeleteNetworkSettings")
DeletePortal = Action("DeletePortal")
DeleteTrustStore = Action("DeleteTrustStore")
DeleteUserSettings = Action("DeleteUserSettings")
DisassociateBrowserSettings = Action("DisassociateBrowserSettings")
DisassociateNetworkSettings = Action("DisassociateNetworkSettings")
DisassociateTrustStore = Action("DisassociateTrustStore")
DisassociateUserSettings = Action("DisassociateUserSettings")
GetBrowserSettings = Action("GetBrowserSettings")
GetIdentityProvider = Action("GetIdentityProvider")
GetNetworkSettings = Action("GetNetworkSettings")
GetPortal = Action("GetPortal")
GetPortalServiceProviderMetadata = Action("GetPortalServiceProviderMetadata")
GetTrustStore = Action("GetTrustStore")
GetTrustStoreCertificate = Action("GetTrustStoreCertificate")
GetUserSettings = Action("GetUserSettings")
ListBrowserSettings = Action("ListBrowserSettings")
ListIdentityProviders = Action("ListIdentityProviders")
ListNetworkSettings = Action("ListNetworkSettings")
ListPortals = Action("ListPortals")
ListTagsForResource = Action("ListTagsForResource")
ListTrustStoreCertificates = Action("ListTrustStoreCertificates")
ListTrustStores = Action("ListTrustStores")
ListUserSettings = Action("ListUserSettings")
TagResource = Action("TagResource")
UntagResource = Action("UntagResource")
UpdateBrowserSettings = Action("UpdateBrowserSettings")
UpdateIdentityProvider = Action("UpdateIdentityProvider")
UpdateNetworkSettings = Action("UpdateNetworkSettings")
UpdatePortal = Action("UpdatePortal")
UpdateTrustStore = Action("UpdateTrustStore")
UpdateUserSettings = Action("UpdateUserSettings")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "AWS CloudHSM"
prefix = "cloudhsm"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


AddTagsToResource = Action("AddTagsToResource")
CopyBackupToRegion = Action("CopyBackupToRegion")
CreateCluster = Action("CreateCluster")
CreateHapg = Action("CreateHapg")
CreateHsm = Action("CreateHsm")
CreateLunaClient = Action("CreateLunaClient")
DeleteBackup = Action("DeleteBackup")
DeleteCluster = Action("DeleteCluster")
DeleteHapg = Action("DeleteHapg")
DeleteHsm = Action("DeleteHsm")
DeleteLunaClient = Action("DeleteLunaClient")
DescribeBackups = Action("DescribeBackups")
DescribeClusters = Action("DescribeClusters")
DescribeHapg = Action("DescribeHapg")
DescribeHsm = Action("DescribeHsm")
DescribeLunaClient = Action("DescribeLunaClient")
GetConfig = Action("GetConfig")
InitializeCluster = Action("InitializeCluster")
ListAvailableZones = Action("ListAvailableZones")
ListHapgs = Action("ListHapgs")
ListHsms = Action("ListHsms")
ListLunaClients = Action("ListLunaClients")
ListTags = Action("ListTags")
ListTagsForResource = Action("ListTagsForResource")
ModifyBackupAttributes = Action("ModifyBackupAttributes")
ModifyCluster = Action("ModifyCluster")
ModifyHapg = Action("ModifyHapg")
ModifyHsm = Action("ModifyHsm")
ModifyLunaClient = Action("ModifyLunaClient")
RemoveTagsFromResource = Action("RemoveTagsFromResource")
RestoreBackup = Action("RestoreBackup")
TagResource = Action("TagResource")
UntagResource = Action("UntagResource")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "Amazon Location"
prefix = "geo"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


AssociateTrackerConsumer = Action("AssociateTrackerConsumer")
BatchDeleteDevicePositionHistory = Action("BatchDeleteDevicePositionHistory")
BatchDeleteGeofence = Action("BatchDeleteGeofence")
BatchEvaluateGeofences = Action("BatchEvaluateGeofences")
BatchGetDevicePosition = Action("BatchGetDevicePosition")
BatchPutGeofence = Action("BatchPutGeofence")
BatchUpdateDevicePosition = Action("BatchUpdateDevicePosition")
CalculateRoute = Action("CalculateRoute")
CalculateRouteMatrix = Action("CalculateRouteMatrix")
CreateGeofenceCollection = Action("CreateGeofenceCollection")
CreateMap = Action("CreateMap")
CreatePlaceIndex = Action("CreatePlaceIndex")
CreateRouteCalculator = Action("CreateRouteCalculator")
CreateTracker = Action("CreateTracker")
DeleteGeofenceCollection = Action("DeleteGeofenceCollection")
DeleteMap = Action("DeleteMap")
DeletePlaceIndex = Action("DeletePlaceIndex")
DeleteRouteCalculator = Action("DeleteRouteCalculator")
DeleteTracker = Action("DeleteTracker")
DescribeGeofenceCollection = Action("DescribeGeofenceCollection")
DescribeMap = Action("DescribeMap")
DescribePlaceIndex = Action("DescribePlaceIndex")
DescribeRouteCalculator = Action("DescribeRouteCalculator")
DescribeTracker = Action("DescribeTracker")
DisassociateTrackerConsumer = Action("DisassociateTrackerConsumer")
GetDevicePosition = Action("GetDevicePosition")
GetDevicePositionHistory = Action("GetDevicePositionHistory")
GetGeofence = Action("GetGeofence")
GetMapGlyphs = Action("GetMapGlyphs")
GetMapSprites = Action("GetMapSprites")
GetMapStyleDescriptor = Action("GetMapStyleDescriptor")
GetMapTile = Action("GetMapTile")
GetMapTileJson = Action("GetMapTileJson")
ListDevicePositions = Action("ListDevicePositions")
ListGeofenceCollections = Action("ListGeofenceCollections")
ListGeofences = Action("ListGeofences")
ListMaps = Action("ListMaps")
ListPlaceIndexes = Action("ListPlaceIndexes")
ListRouteCalculators = Action("ListRouteCalculators")
ListTagsForResource = Action("ListTagsForResource")
ListTrackerConsumers = Action("ListTrackerConsumers")
ListTrackers = Action("ListTrackers")
PutGeofence = Action("PutGeofence")
SearchPlaceIndexForPosition = Action("SearchPlaceIndexForPosition")
SearchPlaceIndexForSuggestions = Action("SearchPlaceIndexForSuggestions")
SearchPlaceIndexForText = Action("SearchPlaceIndexForText")
TagResource = Action("TagResource")
UntagResource = Action("UntagResource")
UpdateGeofenceCollection = Action("UpdateGeofenceCollection")
UpdateMap = Action("UpdateMap")
UpdatePlaceIndex = Action("UpdatePlaceIndex")
UpdateRouteCalculator = Action("UpdateRouteCalculator")
UpdateTracker = Action("UpdateTracker")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "Amazon Inspector2"
prefix = "inspector2"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


AssociateMember = Action("AssociateMember")
BatchGetAccountStatus = Action("BatchGetAccountStatus")
BatchGetFreeTrialInfo = Action("BatchGetFreeTrialInfo")
CancelFindingsReport = Action("CancelFindingsReport")
CreateFilter = Action("CreateFilter")
CreateFindingsReport = Action("CreateFindingsReport")
DeleteFilter = Action("DeleteFilter")
DescribeOrganizationConfiguration = Action("DescribeOrganizationConfiguration")
Disable = Action("Disable")
DisableDelegatedAdminAccount = Action("DisableDelegatedAdminAccount")
DisassociateMember = Action("DisassociateMember")
Enable = Action("Enable")
EnableDelegatedAdminAccount = Action("EnableDelegatedAdminAccount")
GetDelegatedAdminAccount = Action("GetDelegatedAdminAccount")
GetFindingsReportStatus = Action("GetFindingsReportStatus")
GetMember = Action("GetMember")
ListAccountPermissions = Action("ListAccountPermissions")
ListCoverage = Action("ListCoverage")
ListCoverageStatistics = Action("ListCoverageStatistics")
ListDelegatedAdminAccounts = Action("ListDelegatedAdminAccounts")
ListFilters = Action("ListFilters")
ListFindingAggregations = Action("ListFindingAggregations")
ListFindings = Action("ListFindings")
ListMembers = Action("ListMembers")
ListTagsForResource = Action("ListTagsForResource")
ListUsageTotals = Action("ListUsageTotals")
TagResource = Action("TagResource")
UntagResource = Action("UntagResource")
UpdateFilter = Action("UpdateFilter")
UpdateOrganizationConfiguration = Action("UpdateOrganizationConfiguration")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "AWS SQL Workbench"
prefix = "sqlworkbench"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


AssociateConnectionWithChart = Action("AssociateConnectionWithChart")
AssociateConnectionWithTab = Action("AssociateConnectionWithTab")
AssociateQueryWithTab = Action("AssociateQueryWithTab")
BatchDeleteFolder = Action("BatchDeleteFolder")
CreateAccount = Action("CreateAccount")
CreateChart = Action("CreateChart")
CreateConnection = Action("CreateConnection")
CreateFolder = Action("CreateFolder")
CreateSavedQuery = Action("CreateSavedQuery")
DeleteChart = Action("DeleteChart")
DeleteConnection = Action("DeleteConnection")
DeleteSavedQuery = Action("DeleteSavedQuery")
DeleteTab = Action("DeleteTab")
DriverExecute = Action("DriverExecute")
GenerateSession = Action("GenerateSession")
GetAccountInfo = Action("GetAccountInfo")
GetAccountSettings = Action("GetAccountSettings")
GetChart = Action("GetChart")
GetConnection = Action("GetConnection")
GetKMSKey = Action("GetKMSKey")
GetSavedQuery = Action("GetSavedQuery")
GetUserInfo = Action("GetUserInfo")
GetUserWorkspaceSettings = Action("GetUserWorkspaceSettings")
ListBuckets = Action("ListBuckets")
ListConnections = Action("ListConnections")
ListDatabases = Action("ListDatabases")
ListFiles = Action("ListFiles")
ListKMSKeyAliases = Action("ListKMSKeyAliases")
ListKMSKeys = Action("ListKMSKeys")
ListRedshiftClusters = Action("ListRedshiftClusters")
ListSampleDatabases = Action("ListSampleDatabases")
ListSavedQueryVersions = Action("ListSavedQueryVersions")
ListTabs = Action("ListTabs")
ListTaggedResources = Action("ListTaggedResources")
ListTagsForResource = Action("ListTagsForResource")
PutTab = Action("PutTab")
PutUserWorkspaceSettings = Action("PutUserWorkspaceSettings")
TagResource = Action("TagResource")
UntagResource = Action("UntagResource")
UpdateAccountConnectionSettings = Action("UpdateAccountConnectionSettings")
UpdateAccountExportSettings = Action("UpdateAccountExportSettings")
UpdateAccountGeneralSettings = Action("UpdateAccountGeneralSettings")
UpdateChart = Action("UpdateChart")
UpdateConnection = Action("UpdateConnection")
UpdateFileFolder = Action("UpdateFileFolder")
UpdateFolder = Action("UpdateFolder")
UpdateSavedQuery = Action("UpdateSavedQuery")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "AWS Snowball"
prefix = "snowball"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


CancelCluster = Action("CancelCluster")
CancelJob = Action("CancelJob")
CreateAddress = Action("CreateAddress")
CreateCluster = Action("CreateCluster")
CreateJob = Action("CreateJob")
CreateLongTermPricing = Action("CreateLongTermPricing")
CreateReturnShippingLabel = Action("CreateReturnShippingLabel")
DescribeAddress = Action("DescribeAddress")
DescribeAddresses = Action("DescribeAddresses")
DescribeCluster = Action("DescribeCluster")
DescribeJob = Action("DescribeJob")
DescribeReturnShippingLabel = Action("DescribeReturnShippingLabel")
GetJobManifest = Action("GetJobManifest")
GetJobUnlockCode = Action("GetJobUnlockCode")
GetSnowballUsage = Action("GetSnowballUsage")
GetSoftwareUpdates = Action("GetSoftwareUpdates")
ListClusterJobs = Action("ListClusterJobs")
ListClusters = Action("ListClusters")
ListCompatibleImages = Action("ListCompatibleImages")
ListJobs = Action("ListJobs")
ListLongTermPricing = Action("ListLongTermPricing")
UpdateCluster = Action("UpdateCluster")
UpdateJob = Action("UpdateJob")
UpdateJobShipmentState = Action("UpdateJobShipmentState")
UpdateLongTermPricing = Action("UpdateLongTermPricing")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "AWS Panorama"
prefix = "panorama"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


CreateApp = Action("CreateApp")
CreateAppDeployment = Action("CreateAppDeployment")
CreateAppVersion = Action("CreateAppVersion")
CreateApplicationInstance = Action("CreateApplicationInstance")
CreateDataSource = Action("CreateDataSource")
CreateDeploymentConfiguration = Action("CreateDeploymentConfiguration")
CreateDevice = Action("CreateDevice")
CreateDeviceUpdate = Action("CreateDeviceUpdate")
CreateInputs = Action("CreateInputs")
CreateJobForDevices = Action("CreateJobForDevices")
CreateModel = Action("CreateModel")
CreateNodeFromTemplateJob = Action("CreateNodeFromTemplateJob")
CreatePackage = Action("CreatePackage")
CreatePackageImportJob = Action("CreatePackageImportJob")
CreateStreams = Action("CreateStreams")
DeleteApp = Action("DeleteApp")
DeleteAppVersion = Action("DeleteAppVersion")
DeleteDataSource = Action("DeleteDataSource")
DeleteDevice = Action("DeleteDevice")
DeleteModel = Action("DeleteModel")
DeletePackage = Action("DeletePackage")
DeregisterPackageVersion = Action("DeregisterPackageVersion")
DescribeApp = Action("DescribeApp")
DescribeAppDeployment = Action("DescribeAppDeployment")
DescribeAppVersion = Action("DescribeAppVersion")
DescribeApplicationInstance = Action("DescribeApplicationInstance")
DescribeApplicationInstanceDetails = Action("DescribeApplicationInstanceDetails")
DescribeDataSource = Action("DescribeDataSource")
DescribeDevice = Action("DescribeDevice")
DescribeDeviceJob = Action("DescribeDeviceJob")
DescribeDeviceUpdate = Action("DescribeDeviceUpdate")
DescribeModel = Action("DescribeModel")
DescribeNode = Action("DescribeNode")
DescribeNodeFromTemplateJob = Action("DescribeNodeFromTemplateJob")
DescribePackage = Action("DescribePackage")
DescribePackageImportJob = Action("DescribePackageImportJob")
DescribePackageVersion = Action("DescribePackageVersion")
DescribeSoftware = Action("DescribeSoftware")
GetDeploymentConfiguration = Action("GetDeploymentConfiguration")
GetInputs = Action("GetInputs")
GetStreams = Action("GetStreams")
GetWebSocketURL = Action("GetWebSocketURL")
ListAppDeploymentOperations = Action("ListAppDeploymentOperations")
ListAppVersions = Action("ListAppVersions")
ListApplicationInstanceDependencies = Action("ListApplicationInstanceDependencies")
ListApplicationInstanceNodeInstances = Action("ListApplicationInstanceNodeInstances")
ListApplicationInstances = Action("ListApplicationInstances")
ListApps = Action("ListApps")
ListDataSources = Action("ListDataSources")
ListDeploymentConfigurations = Action("ListDeploymentConfigurations")
ListDeviceUpdates = Action("ListDeviceUpdates")
ListDevices = Action("ListDevices")
ListDevicesJobs = Action("ListDevicesJobs")
ListModels = Action("ListModels")
ListNodeFromTemplateJobs = Action("ListNodeFromTemplateJobs")
ListNodes = Action("ListNodes")
ListPackageImportJobs = Action("ListPackageImportJobs")
ListPackages = Action("ListPackages")
ListTagsForResource = Action("ListTagsForResource")
ProvisionDevice = Action("ProvisionDevice")
RegisterPackageVersion = Action("RegisterPackageVersion")
RemoveApplicationInstance = Action("RemoveApplicationInstance")
TagResource = Action("TagResource")
UntagResource = Action("UntagResource")
UpdateApp = Action("UpdateApp")
UpdateAppConfiguration = Action("UpdateAppConfiguration")
UpdateDataSource = Action("UpdateDataSource")
UpdateDevice = Action("UpdateDevice")
UpdateDeviceMetadata = Action("UpdateDeviceMetadata")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "Amazon Rekognition"
prefix = "rekognition"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


CompareFaces = Action("CompareFaces")
CreateCollection = Action("CreateCollection")
CreateDataset = Action("CreateDataset")
CreateProject = Action("CreateProject")
CreateProjectVersion = Action("CreateProjectVersion")
CreateStreamProcessor = Action("CreateStreamProcessor")
DeleteCollection = Action("DeleteCollection")
DeleteDataset = Action("DeleteDataset")
DeleteFaces = Action("DeleteFaces")
DeleteProject = Action("DeleteProject")
DeleteProjectVersion = Action("DeleteProjectVersion")
DeleteStreamProcessor = Action("DeleteStreamProcessor")
DescribeCollection = Action("DescribeCollection")
DescribeDataset = Action("DescribeDataset")
DescribeProjectVersions = Action("DescribeProjectVersions")
DescribeProjects = Action("DescribeProjects")
DescribeStreamProcessor = Action("DescribeStreamProcessor")
DetectCustomLabels = Action("DetectCustomLabels")
DetectFaces = Action("DetectFaces")
DetectLabels = Action("DetectLabels")
DetectModerationLabels = Action("DetectModerationLabels")
DetectProtectiveEquipment = Action("DetectProtectiveEquipment")
DetectText = Action("DetectText")
DistributeDatasetEntries = Action("DistributeDatasetEntries")
GetCelebrityInfo = Action("GetCelebrityInfo")
GetCelebrityRecognition = Action("GetCelebrityRecognition")
GetContentModeration = Action("GetContentModeration")
GetFaceDetection = Action("GetFaceDetection")
GetFaceSearch = Action("GetFaceSearch")
GetLabelDetection = Action("GetLabelDetection")
GetPersonTracking = Action("GetPersonTracking")
GetSegmentDetection = Action("GetSegmentDetection")
GetTextDetection = Action("GetTextDetection")
IndexFaces = Action("IndexFaces")
ListCollections = Action("ListCollections")
ListDatasetEntries = Action("ListDatasetEntries")
ListDatasetLabels = Action("ListDatasetLabels")
ListFaces = Action("ListFaces")
ListStreamProcessors = Action("ListStreamProcessors")
ListTagsForResource = Action("ListTagsForResource")
RecognizeCelebrities = Action("RecognizeCelebrities")
SearchFaces = Action("SearchFaces")
SearchFacesByImage = Action("SearchFacesByImage")
StartCelebrityRecognition = Action("StartCelebrityRecognition")
StartContentModeration = Action("StartContentModeration")
StartFaceDetection = Action("StartFaceDetection")
StartFaceSearch = Action("StartFaceSearch")
StartLabelDetection = Action("StartLabelDetection")
StartPersonTracking = Action("StartPersonTracking")
StartProjectVersion = Action("StartProjectVersion")
StartSegmentDetection = Action("StartSegmentDetection")
StartStreamProcessor = Action("StartStreamProcessor")
StartTextDetection = Action("StartTextDetection")
StopProjectVersion = Action("StopProjectVersion")
StopStreamProcessor = Action("StopStreamProcessor")
TagResource = Action("TagResource")
UntagResource = Action("UntagResource")
UpdateDatasetEntries = Action("UpdateDatasetEntries")
UpdateStreamProcessor = Action("UpdateStreamProcessor")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "Amazon Connect Voice ID"
prefix = "voiceid"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


CreateDomain = Action("CreateDomain")
DeleteDomain = Action("DeleteDomain")
DeleteFraudster = Action("DeleteFraudster")
DeleteSpeaker = Action("DeleteSpeaker")
DescribeComplianceConsent = Action("DescribeComplianceConsent")
DescribeDomain = Action("DescribeDomain")
DescribeFraudster = Action("DescribeFraudster")
DescribeFraudsterRegistrationJob = Action("DescribeFraudsterRegistrationJob")
DescribeSpeaker = Action("DescribeSpeaker")
DescribeSpeakerEnrollmentJob = Action("DescribeSpeakerEnrollmentJob")
EvaluateSession = Action("EvaluateSession")
ListDomains = Action("ListDomains")
ListFraudsterRegistrationJobs = Action("ListFraudsterRegistrationJobs")
ListSpeakerEnrollmentJobs = Action("ListSpeakerEnrollmentJobs")
ListSpeakers = Action("ListSpeakers")
ListTagsForResource = Action("ListTagsForResource")
OptOutSpeaker = Action("OptOutSpeaker")
RegisterComplianceConsent = Action("RegisterComplianceConsent")
StartFraudsterRegistrationJob = Action("StartFraudsterRegistrationJob")
StartSpeakerEnrollmentJob = Action("StartSpeakerEnrollmentJob")
TagResource = Action("TagResource")
UntagResource = Action("UntagResource")
UpdateDomain = Action("UpdateDomain")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "Amazon FSx"
prefix = "fsx"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


AssociateFileGateway = Action("AssociateFileGateway")
AssociateFileSystemAliases = Action("AssociateFileSystemAliases")
CancelDataRepositoryTask = Action("CancelDataRepositoryTask")
CopyBackup = Action("CopyBackup")
CreateBackup = Action("CreateBackup")
CreateDataRepositoryAssociation = Action("CreateDataRepositoryAssociation")
CreateDataRepositoryTask = Action("CreateDataRepositoryTask")
CreateFileSystem = Action("CreateFileSystem")
CreateFileSystemFromBackup = Action("CreateFileSystemFromBackup")
CreateSnapshot = Action("CreateSnapshot")
CreateStorageVirtualMachine = Action("CreateStorageVirtualMachine")
CreateVolume = Action("CreateVolume")
CreateVolumeFromBackup = Action("CreateVolumeFromBackup")
DeleteBackup = Action("DeleteBackup")
DeleteDataRepositoryAssociation = Action("DeleteDataRepositoryAssociation")
DeleteFileSystem = Action("DeleteFileSystem")
DeleteSnapshot = Action("DeleteSnapshot")
DeleteStorageVirtualMachine = Action("DeleteStorageVirtualMachine")
DeleteVolume = Action("DeleteVolume")
DescribeAssociatedFileGateways = Action("DescribeAssociatedFileGateways")
DescribeBackups = Action("DescribeBackups")
DescribeDataRepositoryAssociations = Action("DescribeDataRepositoryAssociations")
DescribeDataRepositoryTasks = Action("DescribeDataRepositoryTasks")
DescribeFileSystemAliases = Action("DescribeFileSystemAliases")
DescribeFileSystems = Action("DescribeFileSystems")
DescribeSnapshots = Action("DescribeSnapshots")
DescribeStorageVirtualMachines = Action("DescribeStorageVirtualMachines")
DescribeVolumes = Action("DescribeVolumes")
DisassociateFileGateway = Action("DisassociateFileGateway")
DisassociateFileSystemAliases = Action("DisassociateFileSystemAliases")
ListTagsForResource = Action("ListTagsForResource")
ManageBackupPrincipalAssociations = Action("ManageBackupPrincipalAssociations")
ReleaseFileSystemNfsV3Locks = Action("ReleaseFileSystemNfsV3Locks")
RestoreVolumeFromSnapshot = Action("RestoreVolumeFromSnapshot")
TagResource = Action("TagResource")
UntagResource = Action("UntagResource")
UpdateDataRepositoryAssociation = Action("UpdateDataRepositoryAssociation")
UpdateFileSystem = Action("UpdateFileSystem")
UpdateSnapshot = Action("UpdateSnapshot")
UpdateStorageVirtualMachine = Action("UpdateStorageVirtualMachine")
UpdateVolume = Action("UpdateVolume")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "AWS IoT Analytics"
prefix = "iotanalytics"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


BatchPutMessage = Action("BatchPutMessage")
CancelPipelineReprocessing = Action("CancelPipelineReprocessing")
CreateChannel = Action("CreateChannel")
CreateDataset = Action("CreateDataset")
CreateDatasetContent = Action("CreateDatasetContent")
CreateDatastore = Action("CreateDatastore")
CreatePipeline = Action("CreatePipeline")
DeleteChannel = Action("DeleteChannel")
DeleteDataset = Action("DeleteDataset")
DeleteDatasetContent = Action("DeleteDatasetContent")
DeleteDatastore = Action("DeleteDatastore")
DeletePipeline = Action("DeletePipeline")
DescribeChannel = Action("DescribeChannel")
DescribeDataset = Action("DescribeDataset")
DescribeDatastore = Action("DescribeDatastore")
DescribeLoggingOptions = Action("DescribeLoggingOptions")
DescribePipeline = Action("DescribePipeline")
GetDatasetContent = Action("GetDatasetContent")
ListChannels = Action("ListChannels")
ListDatasetContents = Action("ListDatasetContents")
ListDatasets = Action("ListDatasets")
ListDatastores = Action("ListDatastores")
ListPipelines = Action("ListPipelines")
ListTagsForResource = Action("ListTagsForResource")
PutLoggingOptions = Action("PutLoggingOptions")
RunPipelineActivity = Action("RunPipelineActivity")
SampleChannelData = Action("SampleChannelData")
StartPipelineReprocessing = Action("StartPipelineReprocessing")
TagResource = Action("TagResource")
UntagResource = Action("UntagResource")
UpdateChannel = Action("UpdateChannel")
UpdateDataset = Action("UpdateDataset")
UpdateDatastore = Action("UpdateDatastore")
UpdatePipeline = Action("UpdatePipeline")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "Amazon EMR Serverless"
prefix = "emr-serverless"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


CancelJobRun = Action("CancelJobRun")
CreateApplication = Action("CreateApplication")
DeleteApplication = Action("DeleteApplication")
GetApplication = Action("GetApplication")
GetJobRun = Action("GetJobRun")
ListApplications = Action("ListApplications")
ListJobRuns = Action("ListJobRuns")
ListTagsForResource = Action("ListTagsForResource")
StartApplication = Action("StartApplication")
StartJobRun = Action("StartJobRun")
StopApplication = Action("StopApplication")
TagResource = Action("TagResource")
UntagResource = Action("UntagResource")
UpdateApplication = Action("UpdateApplication")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "Alexa for Business"
prefix = "a4b"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


ApproveSkill = Action("ApproveSkill")
AssociateContactWithAddressBook = Action("AssociateContactWithAddressBook")
AssociateDeviceWithNetworkProfile = Action("AssociateDeviceWithNetworkProfile")
AssociateDeviceWithRoom = Action("AssociateDeviceWithRoom")
AssociateSkillGroupWithRoom = Action("AssociateSkillGroupWithRoom")
AssociateSkillWithSkillGroup = Action("AssociateSkillWithSkillGroup")
AssociateSkillWithUsers = Action("AssociateSkillWithUsers")
CompleteRegistration = Action("CompleteRegistration")
CreateAddressBook = Action("CreateAddressBook")
CreateBusinessReportSchedule = Action("CreateBusinessReportSchedule")
CreateConferenceProvider = Action("CreateConferenceProvider")
CreateContact = Action("CreateContact")
CreateGatewayGroup = Action("CreateGatewayGroup")
CreateNetworkProfile = Action("CreateNetworkProfile")
CreateProfile = Action("CreateProfile")
CreateRoom = Action("CreateRoom")
CreateSkillGroup = Action("CreateSkillGroup")
CreateUser = Action("CreateUser")
DeleteAddressBook = Action("DeleteAddressBook")
DeleteBusinessReportSchedule = Action("DeleteBusinessReportSchedule")
DeleteConferenceProvider = Action("DeleteConferenceProvider")
DeleteContact = Action("DeleteContact")
DeleteDevice = Action("DeleteDevice")
DeleteDeviceUsageData = Action("DeleteDeviceUsageData")
DeleteGatewayGroup = Action("DeleteGatewayGroup")
DeleteNetworkProfile = Action("DeleteNetworkProfile")
DeleteProfile = Action("DeleteProfile")
DeleteRoom = Action("DeleteRoom")
DeleteRoomSkillParameter = Action("DeleteRoomSkillParameter")
DeleteSkillAuthorization = Action("DeleteSkillAuthorization")
DeleteSkillGroup = Action("DeleteSkillGroup")
DeleteUser = Action("DeleteUser")
DisassociateContactFromAddressBook = Action("DisassociateContactFromAddressBook")
DisassociateDeviceFromRoom = Action("DisassociateDeviceFromRoom")
DisassociateSkillFromSkillGroup = Action("DisassociateSkillFromSkillGroup")
DisassociateSkillFromUsers = Action("DisassociateSkillFromUsers")
DisassociateSkillGroupFromRoom = Action("DisassociateSkillGroupFromRoom")
ForgetSmartHomeAppliances = Action("ForgetSmartHomeAppliances")
GetAddressBook = Action("GetAddressBook")
GetConferencePreference = Action("GetConferencePreference")
GetConferenceProvider = Action("GetConferenceProvider")
GetContact = Action("GetContact")
GetDevice = Action("GetDevice")
GetGateway = Action("GetGateway")
GetGatewayGroup = Action("GetGatewayGroup")
GetInvitationConfiguration = Action("GetInvitationConfiguration")
GetNetworkProfile = Action("GetNetworkProfile")
GetProfile = Action("GetProfile")
GetRoom = Action("GetRoom")
GetRoomSkillParameter = Action("GetRoomSkillParameter")
GetSkillGroup = Action("GetSkillGroup")
ListBusinessReportSchedules = Action("ListBusinessReportSchedules")
ListConferenceProviders = Action("ListConferenceProviders")
ListDeviceEvents = Action("ListDeviceEvents")
ListGatewayGroups = Action("ListGatewayGroups")
ListGateways = Action("ListGateways")
ListSkills = Action("ListSkills")
ListSkillsStoreCategories = Action("ListSkillsStoreCategories")
ListSkillsStoreSkillsByCategory = Action("ListSkillsStoreSkillsByCategory")
ListSmartHomeAppliances = Action("ListSmartHomeAppliances")
ListTags = Action("ListTags")
PutConferencePreference = Action("PutConferencePreference")
PutDeviceSetupEvents = Action("PutDeviceSetupEvents")
PutInvitationConfiguration = Action("PutInvitationConfiguration")
PutRoomSkillParameter = Action("PutRoomSkillParameter")
PutSkillAuthorization = Action("PutSkillAuthorization")
RegisterAVSDevice = Action("RegisterAVSDevice")
RegisterDevice = Action("RegisterDevice")
RejectSkill = Action("RejectSkill")
ResolveRoom = Action("ResolveRoom")
RevokeInvitation = Action("RevokeInvitation")
SearchAddressBooks = Action("SearchAddressBooks")
SearchContacts = Action("SearchContacts")
SearchDevices = Action("SearchDevices")
SearchNetworkProfiles = Action("SearchNetworkProfiles")
SearchProfiles = Action("SearchProfiles")
SearchRooms = Action("SearchRooms")
SearchSkillGroups = Action("SearchSkillGroups")
SearchUsers = Action("SearchUsers")
SendAnnouncement = Action("SendAnnouncement")
SendInvitation = Action("SendInvitation")
StartDeviceSync = Action("StartDeviceSync")
StartSmartHomeApplianceDiscovery = Action("StartSmartHomeApplianceDiscovery")
TagResource = Action("TagResource")
UntagResource = Action("UntagResource")
UpdateAddressBook = Action("UpdateAddressBook")
UpdateBusinessReportSchedule = Action("UpdateBusinessReportSchedule")
UpdateConferenceProvider = Action("UpdateConferenceProvider")
UpdateContact = Action("UpdateContact")
UpdateDevice = Action("UpdateDevice")
UpdateGateway = Action("UpdateGateway")
UpdateGatewayGroup = Action("UpdateGatewayGroup")
UpdateNetworkProfile = Action("UpdateNetworkProfile")
UpdateProfile = Action("UpdateProfile")
UpdateRoom = Action("UpdateRoom")
UpdateSkillGroup = Action("UpdateSkillGroup")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "Amazon Redshift Serverless"
prefix = "redshift-serverless"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


ConvertRecoveryPointToSnapshot = Action("ConvertRecoveryPointToSnapshot")
CreateEndpointAccess = Action("CreateEndpointAccess")
CreateNamespace = Action("CreateNamespace")
CreateSnapshot = Action("CreateSnapshot")
CreateUsageLimit = Action("CreateUsageLimit")
CreateWorkgroup = Action("CreateWorkgroup")
DeleteEndpointAccess = Action("DeleteEndpointAccess")
DeleteNamespace = Action("DeleteNamespace")
DeleteResourcePolicy = Action("DeleteResourcePolicy")
DeleteSnapshot = Action("DeleteSnapshot")
DeleteUsageLimit = Action("DeleteUsageLimit")
DeleteWorkgroup = Action("DeleteWorkgroup")
GetCredentials = Action("GetCredentials")
GetEndpointAccess = Action("GetEndpointAccess")
GetNamespace = Action("GetNamespace")
GetRecoveryPoint = Action("GetRecoveryPoint")
GetResourcePolicy = Action("GetResourcePolicy")
GetSnapshot = Action("GetSnapshot")
GetUsageLimit = Action("GetUsageLimit")
GetWorkgroup = Action("GetWorkgroup")
ListEndpointAccess = Action("ListEndpointAccess")
ListNamespaces = Action("ListNamespaces")
ListRecoveryPoints = Action("ListRecoveryPoints")
ListSnapshots = Action("ListSnapshots")
ListTagsForResource = Action("ListTagsForResource")
ListUsageLimits = Action("ListUsageLimits")
ListWorkgroups = Action("ListWorkgroups")
PutResourcePolicy = Action("PutResourcePolicy")
RestoreFromRecoveryPoint = Action("RestoreFromRecoveryPoint")
RestoreFromSnapshot = Action("RestoreFromSnapshot")
TagResource = Action("TagResource")
UntagResource = Action("UntagResource")
UpdateEndpointAccess = Action("UpdateEndpointAccess")
UpdateNamespace = Action("UpdateNamespace")
UpdateSnapshot = Action("UpdateSnapshot")
UpdateUsageLimit = Action("UpdateUsageLimit")
UpdateWorkgroup = Action("UpdateWorkgroup")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "Amazon Polly"
prefix = "polly"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


DeleteLexicon = Action("DeleteLexicon")
DescribeVoices = Action("DescribeVoices")
GetLexicon = Action("GetLexicon")
GetSpeechSynthesisTask = Action("GetSpeechSynthesisTask")
ListLexicons = Action("ListLexicons")
ListSpeechSynthesisTasks = Action("ListSpeechSynthesisTasks")
PutLexicon = Action("PutLexicon")
StartSpeechSynthesisTask = Action("StartSpeechSynthesisTask")
SynthesizeSpeech = Action("SynthesizeSpeech")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "Amazon Comprehend Medical"
prefix = "comprehendmedical"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


DescribeEntitiesDetectionV2Job = Action("DescribeEntitiesDetectionV2Job")
DescribeICD10CMInferenceJob = Action("DescribeICD10CMInferenceJob")
DescribePHIDetectionJob = Action("DescribePHIDetectionJob")
DescribeRxNormInferenceJob = Action("DescribeRxNormInferenceJob")
DescribeSNOMEDCTInferenceJob = Action("DescribeSNOMEDCTInferenceJob")
DetectEntities = Action("DetectEntities")
DetectEntitiesV2 = Action("DetectEntitiesV2")
DetectPHI = Action("DetectPHI")
InferICD10CM = Action("InferICD10CM")
InferRxNorm = Action("InferRxNorm")
InferSNOMEDCT = Action("InferSNOMEDCT")
ListEntitiesDetectionV2Jobs = Action("ListEntitiesDetectionV2Jobs")
ListICD10CMInferenceJobs = Action("ListICD10CMInferenceJobs")
ListPHIDetectionJobs = Action("ListPHIDetectionJobs")
ListRxNormInferenceJobs = Action("ListRxNormInferenceJobs")
ListSNOMEDCTInferenceJobs = Action("ListSNOMEDCTInferenceJobs")
StartEntitiesDetectionV2Job = Action("StartEntitiesDetectionV2Job")
StartICD10CMInferenceJob = Action("StartICD10CMInferenceJob")
StartPHIDetectionJob = Action("StartPHIDetectionJob")
StartRxNormInferenceJob = Action("StartRxNormInferenceJob")
StartSNOMEDCTInferenceJob = Action("StartSNOMEDCTInferenceJob")
StopEntitiesDetectionV2Job = Action("StopEntitiesDetectionV2Job")
StopICD10CMInferenceJob = Action("StopICD10CMInferenceJob")
StopPHIDetectionJob = Action("StopPHIDetectionJob")
StopRxNormInferenceJob = Action("StopRxNormInferenceJob")
StopSNOMEDCTInferenceJob = Action("StopSNOMEDCTInferenceJob")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "AWS Audit Manager"
prefix = "auditmanager"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


AssociateAssessmentReportEvidenceFolder = Action(
    "AssociateAssessmentReportEvidenceFolder"
)
BatchAssociateAssessmentReportEvidence = Action(
    "BatchAssociateAssessmentReportEvidence"
)
BatchCreateDelegationByAssessment = Action("BatchCreateDelegationByAssessment")
BatchDeleteDelegationByAssessment = Action("BatchDeleteDelegationByAssessment")
BatchDisassociateAssessmentReportEvidence = Action(
    "BatchDisassociateAssessmentReportEvidence"
)
BatchImportEvidenceToAssessmentControl = Action(
    "BatchImportEvidenceToAssessmentControl"
)
CreateAssessment = Action("CreateAssessment")
CreateAssessmentFramework = Action("CreateAssessmentFramework")
CreateAssessmentReport = Action("CreateAssessmentReport")
CreateControl = Action("CreateControl")
DeleteAssessment = Action("DeleteAssessment")
DeleteAssessmentFramework = Action("DeleteAssessmentFramework")
DeleteAssessmentFrameworkShare = Action("DeleteAssessmentFrameworkShare")
DeleteAssessmentReport = Action("DeleteAssessmentReport")
DeleteControl = Action("DeleteControl")
DeregisterAccount = Action("DeregisterAccount")
DeregisterOrganizationAdminAccount = Action("DeregisterOrganizationAdminAccount")
DisassociateAssessmentReportEvidenceFolder = Action(
    "DisassociateAssessmentReportEvidenceFolder"
)
GetAccountStatus = Action("GetAccountStatus")
GetAssessment = Action("GetAssessment")
GetAssessmentFramework = Action("GetAssessmentFramework")
GetAssessmentReportUrl = Action("GetAssessmentReportUrl")
GetChangeLogs = Action("GetChangeLogs")
GetControl = Action("GetControl")
GetDelegations = Action("GetDelegations")
GetEvidence = Action("GetEvidence")
GetEvidenceByEvidenceFolder = Action("GetEvidenceByEvidenceFolder")
GetEvidenceFolder = Action("GetEvidenceFolder")
GetEvidenceFoldersByAssessment = Action("GetEvidenceFoldersByAssessment")
GetEvidenceFoldersByAssessmentControl = Action("GetEvidenceFoldersByAssessmentControl")
GetInsights = Action("GetInsights")
GetInsightsByAssessment = Action("GetInsightsByAssessment")
GetOrganizationAdminAccount = Action("GetOrganizationAdminAccount")
GetServicesInScope = Action("GetServicesInScope")
GetSettings = Action("GetSettings")
ListAssessmentControlInsightsByControlDomain = Action(
    "ListAssessmentControlInsightsByControlDomain"
)
ListAssessmentFrameworkShareRequests = Action("ListAssessmentFrameworkShareRequests")
ListAssessmentFrameworks = Action("ListAssessmentFrameworks")
ListAssessmentReports = Action("ListAssessmentReports")
ListAssessments = Action("ListAssessments")
ListControlDomainInsights = Action("ListControlDomainInsights")
ListControlDomainInsightsByAssessment = Action("ListControlDomainInsightsByAssessment")
ListControlInsightsByControlDomain = Action("ListControlInsightsByControlDomain")
ListControls = Action("ListControls")
ListKeywordsForDataSource = Action("ListKeywordsForDataSource")
ListNotifications = Action("ListNotifications")
ListTagsForResource = Action("ListTagsForResource")
RegisterAccount = Action("RegisterAccount")
RegisterOrganizationAdminAccount = Action("RegisterOrganizationAdminAccount")
StartAssessmentFrameworkShare = Action("StartAssessmentFrameworkShare")
TagResource = Action("TagResource")
UntagResource = Action("UntagResource")
UpdateAssessment = Action("UpdateAssessment")
UpdateAssessmentControl = Action("UpdateAssessmentControl")
UpdateAssessmentControlSetStatus = Action("UpdateAssessmentControlSetStatus")
UpdateAssessmentFramework = Action("UpdateAssessmentFramework")
UpdateAssessmentFrameworkShare = Action("UpdateAssessmentFrameworkShare")
UpdateAssessmentStatus = Action("UpdateAssessmentStatus")
UpdateControl = Action("UpdateControl")
UpdateSettings = Action("UpdateSettings")
ValidateAssessmentReportIntegrity = Action("ValidateAssessmentReportIntegrity")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "AWS Elemental MediaConnect"
prefix = "mediaconnect"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


AddFlowMediaStreams = Action("AddFlowMediaStreams")
AddFlowOutputs = Action("AddFlowOutputs")
AddFlowSources = Action("AddFlowSources")
AddFlowVpcInterfaces = Action("AddFlowVpcInterfaces")
CreateFlow = Action("CreateFlow")
DeleteFlow = Action("DeleteFlow")
DescribeFlow = Action("DescribeFlow")
DescribeOffering = Action("DescribeOffering")
DescribeReservation = Action("DescribeReservation")
GrantFlowEntitlements = Action("GrantFlowEntitlements")
ListEntitlements = Action("ListEntitlements")
ListFlows = Action("ListFlows")
ListOfferings = Action("ListOfferings")
ListReservations = Action("ListReservations")
ListTagsForResource = Action("ListTagsForResource")
PurchaseOffering = Action("PurchaseOffering")
RemoveFlowMediaStream = Action("RemoveFlowMediaStream")
RemoveFlowOutput = Action("RemoveFlowOutput")
RemoveFlowSource = Action("RemoveFlowSource")
RemoveFlowVpcInterface = Action("RemoveFlowVpcInterface")
RevokeFlowEntitlement = Action("RevokeFlowEntitlement")
StartFlow = Action("StartFlow")
StopFlow = Action("StopFlow")
TagResource = Action("TagResource")
UntagResource = Action("UntagResource")
UpdateFlow = Action("UpdateFlow")
UpdateFlowEntitlement = Action("UpdateFlowEntitlement")
UpdateFlowMediaStream = Action("UpdateFlowMediaStream")
UpdateFlowOutput = Action("UpdateFlowOutput")
UpdateFlowSource = Action("UpdateFlowSource")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "Amazon EC2"
prefix = "ec2"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


AcceptReservedInstancesExchangeQuote = Action("AcceptReservedInstancesExchangeQuote")
AcceptTransitGatewayMulticastDomainAssociations = Action(
    "AcceptTransitGatewayMulticastDomainAssociations"
)
AcceptTransitGatewayPeeringAttachment = Action("AcceptTransitGatewayPeeringAttachment")
AcceptTransitGatewayVpcAttachment = Action("AcceptTransitGatewayVpcAttachment")
AcceptVpcEndpointConnections = Action("AcceptVpcEndpointConnections")
AcceptVpcPeeringConnection = Action("AcceptVpcPeeringConnection")
AdvertiseByoipCidr = Action("AdvertiseByoipCidr")
AllocateAddress = Action("AllocateAddress")
AllocateHosts = Action("AllocateHosts")
AllocateIpamPoolCidr = Action("AllocateIpamPoolCidr")
ApplySecurityGroupsToClientVpnTargetNetwork = Action(
    "ApplySecurityGroupsToClientVpnTargetNetwork"
)
AssignIpv6Addresses = Action("AssignIpv6Addresses")
AssignPrivateIpAddresses = Action("AssignPrivateIpAddresses")
AssociateAddress = Action("AssociateAddress")
AssociateClientVpnTargetNetwork = Action("AssociateClientVpnTargetNetwork")
AssociateDhcpOptions = Action("AssociateDhcpOptions")
AssociateEnclaveCertificateIamRole = Action("AssociateEnclaveCertificateIamRole")
AssociateIamInstanceProfile = Action("AssociateIamInstanceProfile")
AssociateInstanceEventWindow = Action("AssociateInstanceEventWindow")
AssociateRouteTable = Action("AssociateRouteTable")
AssociateSubnetCidrBlock = Action("AssociateSubnetCidrBlock")
AssociateTransitGatewayMulticastDomain = Action(
    "AssociateTransitGatewayMulticastDomain"
)
AssociateTransitGatewayPolicyTable = Action("AssociateTransitGatewayPolicyTable")
AssociateTransitGatewayRouteTable = Action("AssociateTransitGatewayRouteTable")
AssociateTrunkInterface = Action("AssociateTrunkInterface")
AssociateVpcCidrBlock = Action("AssociateVpcCidrBlock")
AttachClassicLinkVpc = Action("AttachClassicLinkVpc")
AttachInternetGateway = Action("AttachInternetGateway")
AttachNetworkInterface = Action("AttachNetworkInterface")
AttachVolume = Action("AttachVolume")
AttachVpnGateway = Action("AttachVpnGateway")
AuthorizeClientVpnIngress = Action("AuthorizeClientVpnIngress")
AuthorizeSecurityGroupEgress = Action("AuthorizeSecurityGroupEgress")
AuthorizeSecurityGroupIngress = Action("AuthorizeSecurityGroupIngress")
BundleInstance = Action("BundleInstance")
CancelBundleTask = Action("CancelBundleTask")
CancelCapacityReservation = Action("CancelCapacityReservation")
CancelCapacityReservationFleets = Action("CancelCapacityReservationFleets")
CancelConversionTask = Action("CancelConversionTask")
CancelExportTask = Action("CancelExportTask")
CancelImportTask = Action("CancelImportTask")
CancelReservedInstancesListing = Action("CancelReservedInstancesListing")
CancelSpotFleetRequests = Action("CancelSpotFleetRequests")
CancelSpotInstanceRequests = Action("CancelSpotInstanceRequests")
ConfirmProductInstance = Action("ConfirmProductInstance")
CopyFpgaImage = Action("CopyFpgaImage")
CopyImage = Action("CopyImage")
CopySnapshot = Action("CopySnapshot")
CreateCapacityReservation = Action("CreateCapacityReservation")
CreateCapacityReservationFleet = Action("CreateCapacityReservationFleet")
CreateCarrierGateway = Action("CreateCarrierGateway")
CreateClientVpnEndpoint = Action("CreateClientVpnEndpoint")
CreateClientVpnRoute = Action("CreateClientVpnRoute")
CreateCoipPoolPermission = Action("CreateCoipPoolPermission")
CreateCustomerGateway = Action("CreateCustomerGateway")
CreateDefaultSubnet = Action("CreateDefaultSubnet")
CreateDefaultVpc = Action("CreateDefaultVpc")
CreateDhcpOptions = Action("CreateDhcpOptions")
CreateEgressOnlyInternetGateway = Action("CreateEgressOnlyInternetGateway")
CreateFleet = Action("CreateFleet")
CreateFlowLogs = Action("CreateFlowLogs")
CreateFpgaImage = Action("CreateFpgaImage")
CreateImage = Action("CreateImage")
CreateInstanceEventWindow = Action("CreateInstanceEventWindow")
CreateInstanceExportTask = Action("CreateInstanceExportTask")
CreateInternetGateway = Action("CreateInternetGateway")
CreateIpam = Action("CreateIpam")
CreateIpamPool = Action("CreateIpamPool")
CreateIpamScope = Action("CreateIpamScope")
CreateKeyPair = Action("CreateKeyPair")
CreateLaunchTemplate = Action("CreateLaunchTemplate")
CreateLaunchTemplateVersion = Action("CreateLaunchTemplateVersion")
CreateLocalGatewayRoute = Action("CreateLocalGatewayRoute")
CreateLocalGatewayRouteTablePermission = Action(
    "CreateLocalGatewayRouteTablePermission"
)
CreateLocalGatewayRouteTableVpcAssociation = Action(
    "CreateLocalGatewayRouteTableVpcAssociation"
)
CreateManagedPrefixList = Action("CreateManagedPrefixList")
CreateNatGateway = Action("CreateNatGateway")
CreateNetworkAcl = Action("CreateNetworkAcl")
CreateNetworkAclEntry = Action("CreateNetworkAclEntry")
CreateNetworkInsightsAccessScope = Action("CreateNetworkInsightsAccessScope")
CreateNetworkInsightsPath = Action("CreateNetworkInsightsPath")
CreateNetworkInterface = Action("CreateNetworkInterface")
CreateNetworkInterfacePermission = Action("CreateNetworkInterfacePermission")
CreatePlacementGroup = Action("CreatePlacementGroup")
CreatePublicIpv4Pool = Action("CreatePublicIpv4Pool")
CreateReplaceRootVolumeTask = Action("CreateReplaceRootVolumeTask")
CreateReservedInstancesListing = Action("CreateReservedInstancesListing")
CreateRestoreImageTask = Action("CreateRestoreImageTask")
CreateRoute = Action("CreateRoute")
CreateRouteTable = Action("CreateRouteTable")
CreateSecurityGroup = Action("CreateSecurityGroup")
CreateSnapshot = Action("CreateSnapshot")
CreateSnapshots = Action("CreateSnapshots")
CreateSpotDatafeedSubscription = Action("CreateSpotDatafeedSubscription")
CreateStoreImageTask = Action("CreateStoreImageTask")
CreateSubnet = Action("CreateSubnet")
CreateSubnetCidrReservation = Action("CreateSubnetCidrReservation")
CreateTags = Action("CreateTags")
CreateTrafficMirrorFilter = Action("CreateTrafficMirrorFilter")
CreateTrafficMirrorFilterRule = Action("CreateTrafficMirrorFilterRule")
CreateTrafficMirrorSession = Action("CreateTrafficMirrorSession")
CreateTrafficMirrorTarget = Action("CreateTrafficMirrorTarget")
CreateTransitGateway = Action("CreateTransitGateway")
CreateTransitGatewayConnect = Action("CreateTransitGatewayConnect")
CreateTransitGatewayConnectPeer = Action("CreateTransitGatewayConnectPeer")
CreateTransitGatewayMulticastDomain = Action("CreateTransitGatewayMulticastDomain")
CreateTransitGatewayPeeringAttachment = Action("CreateTransitGatewayPeeringAttachment")
CreateTransitGatewayPolicyTable = Action("CreateTransitGatewayPolicyTable")
CreateTransitGatewayPrefixListReference = Action(
    "CreateTransitGatewayPrefixListReference"
)
CreateTransitGatewayRoute = Action("CreateTransitGatewayRoute")
CreateTransitGatewayRouteTable = Action("CreateTransitGatewayRouteTable")
CreateTransitGatewayRouteTableAnnouncement = Action(
    "CreateTransitGatewayRouteTableAnnouncement"
)
CreateTransitGatewayVpcAttachment = Action("CreateTransitGatewayVpcAttachment")
CreateVolume = Action("CreateVolume")
CreateVpc = Action("CreateVpc")
CreateVpcEndpoint = Action("CreateVpcEndpoint")
CreateVpcEndpointConnectionNotification = Action(
    "CreateVpcEndpointConnectionNotification"
)
CreateVpcEndpointServiceConfiguration = Action("CreateVpcEndpointServiceConfiguration")
CreateVpcPeeringConnection = Action("CreateVpcPeeringConnection")
CreateVpnConnection = Action("CreateVpnConnection")
CreateVpnConnectionRoute = Action("CreateVpnConnectionRoute")
CreateVpnGateway = Action("CreateVpnGateway")
DeleteCarrierGateway = Action("DeleteCarrierGateway")
DeleteClientVpnEndpoint = Action("DeleteClientVpnEndpoint")
DeleteClientVpnRoute = Action("DeleteClientVpnRoute")
DeleteCoipPoolPermission = Action("DeleteCoipPoolPermission")
DeleteCustomerGateway = Action("DeleteCustomerGateway")
DeleteDhcpOptions = Action("DeleteDhcpOptions")
DeleteEgressOnlyInternetGateway = Action("DeleteEgressOnlyInternetGateway")
DeleteFleets = Action("DeleteFleets")
DeleteFlowLogs = Action("DeleteFlowLogs")
DeleteFpgaImage = Action("DeleteFpgaImage")
DeleteInstanceEventWindow = Action("DeleteInstanceEventWindow")
DeleteInternetGateway = Action("DeleteInternetGateway")
DeleteIpam = Action("DeleteIpam")
DeleteIpamPool = Action("DeleteIpamPool")
DeleteIpamScope = Action("DeleteIpamScope")
DeleteKeyPair = Action("DeleteKeyPair")
DeleteLaunchTemplate = Action("DeleteLaunchTemplate")
DeleteLaunchTemplateVersions = Action("DeleteLaunchTemplateVersions")
DeleteLocalGatewayRoute = Action("DeleteLocalGatewayRoute")
DeleteLocalGatewayRouteTablePermission = Action(
    "DeleteLocalGatewayRouteTablePermission"
)
DeleteLocalGatewayRouteTableVpcAssociation = Action(
    "DeleteLocalGatewayRouteTableVpcAssociation"
)
DeleteManagedPrefixList = Action("DeleteManagedPrefixList")
DeleteNatGateway = Action("DeleteNatGateway")
DeleteNetworkAcl = Action("DeleteNetworkAcl")
DeleteNetworkAclEntry = Action("DeleteNetworkAclEntry")
DeleteNetworkInsightsAccessScope = Action("DeleteNetworkInsightsAccessScope")
DeleteNetworkInsightsAccessScopeAnalysis = Action(
    "DeleteNetworkInsightsAccessScopeAnalysis"
)
DeleteNetworkInsightsAnalysis = Action("DeleteNetworkInsightsAnalysis")
DeleteNetworkInsightsPath = Action("DeleteNetworkInsightsPath")
DeleteNetworkInterface = Action("DeleteNetworkInterface")
DeleteNetworkInterfacePermission = Action("DeleteNetworkInterfacePermission")
DeletePlacementGroup = Action("DeletePlacementGroup")
DeletePublicIpv4Pool = Action("DeletePublicIpv4Pool")
DeleteQueuedReservedInstances = Action("DeleteQueuedReservedInstances")
DeleteResourcePolicy = Action("DeleteResourcePolicy")
DeleteRoute = Action("DeleteRoute")
DeleteRouteTable = Action("DeleteRouteTable")
DeleteSecurityGroup = Action("DeleteSecurityGroup")
DeleteSnapshot = Action("DeleteSnapshot")
DeleteSpotDatafeedSubscription = Action("DeleteSpotDatafeedSubscription")
DeleteSubnet = Action("DeleteSubnet")
DeleteSubnetCidrReservation = Action("DeleteSubnetCidrReservation")
DeleteTags = Action("DeleteTags")
DeleteTrafficMirrorFilter = Action("DeleteTrafficMirrorFilter")
DeleteTrafficMirrorFilterRule = Action("DeleteTrafficMirrorFilterRule")
DeleteTrafficMirrorSession = Action("DeleteTrafficMirrorSession")
DeleteTrafficMirrorTarget = Action("DeleteTrafficMirrorTarget")
DeleteTransitGateway = Action("DeleteTransitGateway")
DeleteTransitGatewayConnect = Action("DeleteTransitGatewayConnect")
DeleteTransitGatewayConnectPeer = Action("DeleteTransitGatewayConnectPeer")
DeleteTransitGatewayMulticastDomain = Action("DeleteTransitGatewayMulticastDomain")
DeleteTransitGatewayPeeringAttachment = Action("DeleteTransitGatewayPeeringAttachment")
DeleteTransitGatewayPolicyTable = Action("DeleteTransitGatewayPolicyTable")
DeleteTransitGatewayPrefixListReference = Action(
    "DeleteTransitGatewayPrefixListReference"
)
DeleteTransitGatewayRoute = Action("DeleteTransitGatewayRoute")
DeleteTransitGatewayRouteTable = Action("DeleteTransitGatewayRouteTable")
DeleteTransitGatewayRouteTableAnnouncement = Action(
    "DeleteTransitGatewayRouteTableAnnouncement"
)
DeleteTransitGatewayVpcAttachment = Action("DeleteTransitGatewayVpcAttachment")
DeleteVolume = Action("DeleteVolume")
DeleteVpc = Action("DeleteVpc")
DeleteVpcEndpointConnectionNotifications = Action(
    "DeleteVpcEndpointConnectionNotifications"
)
DeleteVpcEndpointServiceConfigurations = Action(
    "DeleteVpcEndpointServiceConfigurations"
)
DeleteVpcEndpoints = Action("DeleteVpcEndpoints")
DeleteVpcPeeringConnection = Action("DeleteVpcPeeringConnection")
DeleteVpnConnection = Action("DeleteVpnConnection")
DeleteVpnConnectionRoute = Action("DeleteVpnConnectionRoute")
DeleteVpnGateway = Action("DeleteVpnGateway")
DeprovisionByoipCidr = Action("DeprovisionByoipCidr")
DeprovisionIpamPoolCidr = Action("DeprovisionIpamPoolCidr")
DeprovisionPublicIpv4PoolCidr = Action("DeprovisionPublicIpv4PoolCidr")
DeregisterImage = Action("DeregisterImage")
DeregisterInstanceEventNotificationAttributes = Action(
    "DeregisterInstanceEventNotificationAttributes"
)
DeregisterTransitGatewayMulticastGroupMembers = Action(
    "DeregisterTransitGatewayMulticastGroupMembers"
)
DeregisterTransitGatewayMulticastGroupSources = Action(
    "DeregisterTransitGatewayMulticastGroupSources"
)
DescribeAccountAttributes = Action("DescribeAccountAttributes")
DescribeAddresses = Action("DescribeAddresses")
DescribeAddressesAttribute = Action("DescribeAddressesAttribute")
DescribeAggregateIdFormat = Action("DescribeAggregateIdFormat")
DescribeAvailabilityZones = Action("DescribeAvailabilityZones")
DescribeBundleTasks = Action("DescribeBundleTasks")
DescribeByoipCidrs = Action("DescribeByoipCidrs")
DescribeCapacityReservationFleets = Action("DescribeCapacityReservationFleets")
DescribeCapacityReservations = Action("DescribeCapacityReservations")
DescribeCarrierGateways = Action("DescribeCarrierGateways")
DescribeClassicLinkInstances = Action("DescribeClassicLinkInstances")
DescribeClientVpnAuthorizationRules = Action("DescribeClientVpnAuthorizationRules")
DescribeClientVpnConnections = Action("DescribeClientVpnConnections")
DescribeClientVpnEndpoints = Action("DescribeClientVpnEndpoints")
DescribeClientVpnRoutes = Action("DescribeClientVpnRoutes")
DescribeClientVpnTargetNetworks = Action("DescribeClientVpnTargetNetworks")
DescribeCoipPools = Action("DescribeCoipPools")
DescribeConversionTasks = Action("DescribeConversionTasks")
DescribeCustomerGateways = Action("DescribeCustomerGateways")
DescribeDhcpOptions = Action("DescribeDhcpOptions")
DescribeEgressOnlyInternetGateways = Action("DescribeEgressOnlyInternetGateways")
DescribeElasticGpus = Action("DescribeElasticGpus")
DescribeExportImageTasks = Action("DescribeExportImageTasks")
DescribeExportTasks = Action("DescribeExportTasks")
DescribeFastLaunchImages = Action("DescribeFastLaunchImages")
DescribeFastSnapshotRestores = Action("DescribeFastSnapshotRestores")
DescribeFleetHistory = Action("DescribeFleetHistory")
DescribeFleetInstances = Action("DescribeFleetInstances")
DescribeFleets = Action("DescribeFleets")
DescribeFlowLogs = Action("DescribeFlowLogs")
DescribeFpgaImageAttribute = Action("DescribeFpgaImageAttribute")
DescribeFpgaImages = Action("DescribeFpgaImages")
DescribeHostReservationOfferings = Action("DescribeHostReservationOfferings")
DescribeHostReservations = Action("DescribeHostReservations")
DescribeHosts = Action("DescribeHosts")
DescribeIamInstanceProfileAssociations = Action(
    "DescribeIamInstanceProfileAssociations"
)
DescribeIdFormat = Action("DescribeIdFormat")
DescribeIdentityIdFormat = Action("DescribeIdentityIdFormat")
DescribeImageAttribute = Action("DescribeImageAttribute")
DescribeImages = Action("DescribeImages")
DescribeImportImageTasks = Action("DescribeImportImageTasks")
DescribeImportSnapshotTasks = Action("DescribeImportSnapshotTasks")
DescribeInstanceAttribute = Action("DescribeInstanceAttribute")
DescribeInstanceCreditSpecifications = Action("DescribeInstanceCreditSpecifications")
DescribeInstanceEventNotificationAttributes = Action(
    "DescribeInstanceEventNotificationAttributes"
)
DescribeInstanceEventWindows = Action("DescribeInstanceEventWindows")
DescribeInstanceStatus = Action("DescribeInstanceStatus")
DescribeInstanceTypeOfferings = Action("DescribeInstanceTypeOfferings")
DescribeInstanceTypes = Action("DescribeInstanceTypes")
DescribeInstances = Action("DescribeInstances")
DescribeInternetGateways = Action("DescribeInternetGateways")
DescribeIpamPools = Action("DescribeIpamPools")
DescribeIpamScopes = Action("DescribeIpamScopes")
DescribeIpams = Action("DescribeIpams")
DescribeIpv6Pools = Action("DescribeIpv6Pools")
DescribeKeyPairs = Action("DescribeKeyPairs")
DescribeLaunchTemplateVersions = Action("DescribeLaunchTemplateVersions")
DescribeLaunchTemplates = Action("DescribeLaunchTemplates")
DescribeLocalGatewayRouteTablePermissions = Action(
    "DescribeLocalGatewayRouteTablePermissions"
)
DescribeLocalGatewayRouteTableVirtualInterfaceGroupAssociations = Action(
    "DescribeLocalGatewayRouteTableVirtualInterfaceGroupAssociations"
)
DescribeLocalGatewayRouteTableVpcAssociations = Action(
    "DescribeLocalGatewayRouteTableVpcAssociations"
)
DescribeLocalGatewayRouteTables = Action("DescribeLocalGatewayRouteTables")
DescribeLocalGatewayVirtualInterfaceGroups = Action(
    "DescribeLocalGatewayVirtualInterfaceGroups"
)
DescribeLocalGatewayVirtualInterfaces = Action("DescribeLocalGatewayVirtualInterfaces")
DescribeLocalGateways = Action("DescribeLocalGateways")
DescribeManagedPrefixLists = Action("DescribeManagedPrefixLists")
DescribeMovingAddresses = Action("DescribeMovingAddresses")
DescribeNatGateways = Action("DescribeNatGateways")
DescribeNetworkAcls = Action("DescribeNetworkAcls")
DescribeNetworkInsightsAccessScopeAnalyses = Action(
    "DescribeNetworkInsightsAccessScopeAnalyses"
)
DescribeNetworkInsightsAccessScopes = Action("DescribeNetworkInsightsAccessScopes")
DescribeNetworkInsightsAnalyses = Action("DescribeNetworkInsightsAnalyses")
DescribeNetworkInsightsPaths = Action("DescribeNetworkInsightsPaths")
DescribeNetworkInterfaceAttribute = Action("DescribeNetworkInterfaceAttribute")
DescribeNetworkInterfacePermissions = Action("DescribeNetworkInterfacePermissions")
DescribeNetworkInterfaces = Action("DescribeNetworkInterfaces")
DescribePlacementGroups = Action("DescribePlacementGroups")
DescribePrefixLists = Action("DescribePrefixLists")
DescribePrincipalIdFormat = Action("DescribePrincipalIdFormat")
DescribePublicIpv4Pools = Action("DescribePublicIpv4Pools")
DescribeRegions = Action("DescribeRegions")
DescribeReplaceRootVolumeTasks = Action("DescribeReplaceRootVolumeTasks")
DescribeReservedInstances = Action("DescribeReservedInstances")
DescribeReservedInstancesListings = Action("DescribeReservedInstancesListings")
DescribeReservedInstancesModifications = Action(
    "DescribeReservedInstancesModifications"
)
DescribeReservedInstancesOfferings = Action("DescribeReservedInstancesOfferings")
DescribeRouteTables = Action("DescribeRouteTables")
DescribeScheduledInstanceAvailability = Action("DescribeScheduledInstanceAvailability")
DescribeScheduledInstances = Action("DescribeScheduledInstances")
DescribeSecurityGroupReferences = Action("DescribeSecurityGroupReferences")
DescribeSecurityGroupRules = Action("DescribeSecurityGroupRules")
DescribeSecurityGroups = Action("DescribeSecurityGroups")
DescribeSnapshotAttribute = Action("DescribeSnapshotAttribute")
DescribeSnapshotTierStatus = Action("DescribeSnapshotTierStatus")
DescribeSnapshots = Action("DescribeSnapshots")
DescribeSpotDatafeedSubscription = Action("DescribeSpotDatafeedSubscription")
DescribeSpotFleetInstances = Action("DescribeSpotFleetInstances")
DescribeSpotFleetRequestHistory = Action("DescribeSpotFleetRequestHistory")
DescribeSpotFleetRequests = Action("DescribeSpotFleetRequests")
DescribeSpotInstanceRequests = Action("DescribeSpotInstanceRequests")
DescribeSpotPriceHistory = Action("DescribeSpotPriceHistory")
DescribeStaleSecurityGroups = Action("DescribeStaleSecurityGroups")
DescribeStoreImageTasks = Action("DescribeStoreImageTasks")
DescribeSubnets = Action("DescribeSubnets")
DescribeTags = Action("DescribeTags")
DescribeTrafficMirrorFilters = Action("DescribeTrafficMirrorFilters")
DescribeTrafficMirrorSessions = Action("DescribeTrafficMirrorSessions")
DescribeTrafficMirrorTargets = Action("DescribeTrafficMirrorTargets")
DescribeTransitGatewayAttachments = Action("DescribeTransitGatewayAttachments")
DescribeTransitGatewayConnectPeers = Action("DescribeTransitGatewayConnectPeers")
DescribeTransitGatewayConnects = Action("DescribeTransitGatewayConnects")
DescribeTransitGatewayMulticastDomains = Action(
    "DescribeTransitGatewayMulticastDomains"
)
DescribeTransitGatewayPeeringAttachments = Action(
    "DescribeTransitGatewayPeeringAttachments"
)
DescribeTransitGatewayPolicyTables = Action("DescribeTransitGatewayPolicyTables")
DescribeTransitGatewayRouteTableAnnouncements = Action(
    "DescribeTransitGatewayRouteTableAnnouncements"
)
DescribeTransitGatewayRouteTables = Action("DescribeTransitGatewayRouteTables")
DescribeTransitGatewayVpcAttachments = Action("DescribeTransitGatewayVpcAttachments")
DescribeTransitGateways = Action("DescribeTransitGateways")
DescribeTrunkInterfaceAssociations = Action("DescribeTrunkInterfaceAssociations")
DescribeVolumeAttribute = Action("DescribeVolumeAttribute")
DescribeVolumeStatus = Action("DescribeVolumeStatus")
DescribeVolumes = Action("DescribeVolumes")
DescribeVolumesModifications = Action("DescribeVolumesModifications")
DescribeVpcAttribute = Action("DescribeVpcAttribute")
DescribeVpcClassicLink = Action("DescribeVpcClassicLink")
DescribeVpcClassicLinkDnsSupport = Action("DescribeVpcClassicLinkDnsSupport")
DescribeVpcEndpointConnectionNotifications = Action(
    "DescribeVpcEndpointConnectionNotifications"
)
DescribeVpcEndpointConnections = Action("DescribeVpcEndpointConnections")
DescribeVpcEndpointServiceConfigurations = Action(
    "DescribeVpcEndpointServiceConfigurations"
)
DescribeVpcEndpointServicePermissions = Action("DescribeVpcEndpointServicePermissions")
DescribeVpcEndpointServices = Action("DescribeVpcEndpointServices")
DescribeVpcEndpoints = Action("DescribeVpcEndpoints")
DescribeVpcPeeringConnections = Action("DescribeVpcPeeringConnections")
DescribeVpcs = Action("DescribeVpcs")
DescribeVpnConnections = Action("DescribeVpnConnections")
DescribeVpnGateways = Action("DescribeVpnGateways")
DetachClassicLinkVpc = Action("DetachClassicLinkVpc")
DetachInternetGateway = Action("DetachInternetGateway")
DetachNetworkInterface = Action("DetachNetworkInterface")
DetachVolume = Action("DetachVolume")
DetachVpnGateway = Action("DetachVpnGateway")
DisableEbsEncryptionByDefault = Action("DisableEbsEncryptionByDefault")
DisableFastLaunch = Action("DisableFastLaunch")
DisableFastSnapshotRestores = Action("DisableFastSnapshotRestores")
DisableImageDeprecation = Action("DisableImageDeprecation")
DisableIpamOrganizationAdminAccount = Action("DisableIpamOrganizationAdminAccount")
DisableSerialConsoleAccess = Action("DisableSerialConsoleAccess")
DisableTransitGatewayRouteTablePropagation = Action(
    "DisableTransitGatewayRouteTablePropagation"
)
DisableVgwRoutePropagation = Action("DisableVgwRoutePropagation")
DisableVpcClassicLink = Action("DisableVpcClassicLink")
DisableVpcClassicLinkDnsSupport = Action("DisableVpcClassicLinkDnsSupport")
DisassociateAddress = Action("DisassociateAddress")
DisassociateClientVpnTargetNetwork = Action("DisassociateClientVpnTargetNetwork")
DisassociateEnclaveCertificateIamRole = Action("DisassociateEnclaveCertificateIamRole")
DisassociateIamInstanceProfile = Action("DisassociateIamInstanceProfile")
DisassociateInstanceEventWindow = Action("DisassociateInstanceEventWindow")
DisassociateRouteTable = Action("DisassociateRouteTable")
DisassociateSubnetCidrBlock = Action("DisassociateSubnetCidrBlock")
DisassociateTransitGatewayMulticastDomain = Action(
    "DisassociateTransitGatewayMulticastDomain"
)
DisassociateTransitGatewayPolicyTable = Action("DisassociateTransitGatewayPolicyTable")
DisassociateTransitGatewayRouteTable = Action("DisassociateTransitGatewayRouteTable")
DisassociateTrunkInterface = Action("DisassociateTrunkInterface")
DisassociateVpcCidrBlock = Action("DisassociateVpcCidrBlock")
EnableEbsEncryptionByDefault = Action("EnableEbsEncryptionByDefault")
EnableFastLaunch = Action("EnableFastLaunch")
EnableFastSnapshotRestores = Action("EnableFastSnapshotRestores")
EnableImageDeprecation = Action("EnableImageDeprecation")
EnableIpamOrganizationAdminAccount = Action("EnableIpamOrganizationAdminAccount")
EnableSerialConsoleAccess = Action("EnableSerialConsoleAccess")
EnableTransitGatewayRouteTablePropagation = Action(
    "EnableTransitGatewayRouteTablePropagation"
)
EnableVgwRoutePropagation = Action("EnableVgwRoutePropagation")
EnableVolumeIO = Action("EnableVolumeIO")
EnableVpcClassicLink = Action("EnableVpcClassicLink")
EnableVpcClassicLinkDnsSupport = Action("EnableVpcClassicLinkDnsSupport")
ExportClientVpnClientCertificateRevocationList = Action(
    "ExportClientVpnClientCertificateRevocationList"
)
ExportClientVpnClientConfiguration = Action("ExportClientVpnClientConfiguration")
ExportImage = Action("ExportImage")
ExportTransitGatewayRoutes = Action("ExportTransitGatewayRoutes")
GetAssociatedEnclaveCertificateIamRoles = Action(
    "GetAssociatedEnclaveCertificateIamRoles"
)
GetAssociatedIpv6PoolCidrs = Action("GetAssociatedIpv6PoolCidrs")
GetCapacityReservationUsage = Action("GetCapacityReservationUsage")
GetCoipPoolUsage = Action("GetCoipPoolUsage")
GetConsoleOutput = Action("GetConsoleOutput")
GetConsoleScreenshot = Action("GetConsoleScreenshot")
GetDefaultCreditSpecification = Action("GetDefaultCreditSpecification")
GetEbsDefaultKmsKeyId = Action("GetEbsDefaultKmsKeyId")
GetEbsEncryptionByDefault = Action("GetEbsEncryptionByDefault")
GetFlowLogsIntegrationTemplate = Action("GetFlowLogsIntegrationTemplate")
GetGroupsForCapacityReservation = Action("GetGroupsForCapacityReservation")
GetHostReservationPurchasePreview = Action("GetHostReservationPurchasePreview")
GetInstanceTypesFromInstanceRequirements = Action(
    "GetInstanceTypesFromInstanceRequirements"
)
GetInstanceUefiData = Action("GetInstanceUefiData")
GetIpamAddressHistory = Action("GetIpamAddressHistory")
GetIpamPoolAllocations = Action("GetIpamPoolAllocations")
GetIpamPoolCidrs = Action("GetIpamPoolCidrs")
GetIpamResourceCidrs = Action("GetIpamResourceCidrs")
GetLaunchTemplateData = Action("GetLaunchTemplateData")
GetManagedPrefixListAssociations = Action("GetManagedPrefixListAssociations")
GetManagedPrefixListEntries = Action("GetManagedPrefixListEntries")
GetNetworkInsightsAccessScopeAnalysisFindings = Action(
    "GetNetworkInsightsAccessScopeAnalysisFindings"
)
GetNetworkInsightsAccessScopeContent = Action("GetNetworkInsightsAccessScopeContent")
GetPasswordData = Action("GetPasswordData")
GetReservedInstancesExchangeQuote = Action("GetReservedInstancesExchangeQuote")
GetResourcePolicy = Action("GetResourcePolicy")
GetSerialConsoleAccessStatus = Action("GetSerialConsoleAccessStatus")
GetSpotPlacementScores = Action("GetSpotPlacementScores")
GetSubnetCidrReservations = Action("GetSubnetCidrReservations")
GetTransitGatewayAttachmentPropagations = Action(
    "GetTransitGatewayAttachmentPropagations"
)
GetTransitGatewayMulticastDomainAssociations = Action(
    "GetTransitGatewayMulticastDomainAssociations"
)
GetTransitGatewayPolicyTableAssociations = Action(
    "GetTransitGatewayPolicyTableAssociations"
)
GetTransitGatewayPolicyTableEntries = Action("GetTransitGatewayPolicyTableEntries")
GetTransitGatewayPrefixListReferences = Action("GetTransitGatewayPrefixListReferences")
GetTransitGatewayRouteTableAssociations = Action(
    "GetTransitGatewayRouteTableAssociations"
)
GetTransitGatewayRouteTablePropagations = Action(
    "GetTransitGatewayRouteTablePropagations"
)
GetVpnConnectionDeviceSampleConfiguration = Action(
    "GetVpnConnectionDeviceSampleConfiguration"
)
GetVpnConnectionDeviceTypes = Action("GetVpnConnectionDeviceTypes")
ImportClientVpnClientCertificateRevocationList = Action(
    "ImportClientVpnClientCertificateRevocationList"
)
ImportImage = Action("ImportImage")
ImportInstance = Action("ImportInstance")
ImportKeyPair = Action("ImportKeyPair")
ImportSnapshot = Action("ImportSnapshot")
ImportVolume = Action("ImportVolume")
ListImagesInRecycleBin = Action("ListImagesInRecycleBin")
ListSnapshotsInRecycleBin = Action("ListSnapshotsInRecycleBin")
ModifyAddressAttribute = Action("ModifyAddressAttribute")
ModifyAvailabilityZoneGroup = Action("ModifyAvailabilityZoneGroup")
ModifyCapacityReservation = Action("ModifyCapacityReservation")
ModifyCapacityReservationFleet = Action("ModifyCapacityReservationFleet")
ModifyClientVpnEndpoint = Action("ModifyClientVpnEndpoint")
ModifyDefaultCreditSpecification = Action("ModifyDefaultCreditSpecification")
ModifyEbsDefaultKmsKeyId = Action("ModifyEbsDefaultKmsKeyId")
ModifyFleet = Action("ModifyFleet")
ModifyFpgaImageAttribute = Action("ModifyFpgaImageAttribute")
ModifyHosts = Action("ModifyHosts")
ModifyIdFormat = Action("ModifyIdFormat")
ModifyIdentityIdFormat = Action("ModifyIdentityIdFormat")
ModifyImageAttribute = Action("ModifyImageAttribute")
ModifyInstanceAttribute = Action("ModifyInstanceAttribute")
ModifyInstanceCapacityReservationAttributes = Action(
    "ModifyInstanceCapacityReservationAttributes"
)
ModifyInstanceCreditSpecification = Action("ModifyInstanceCreditSpecification")
ModifyInstanceEventStartTime = Action("ModifyInstanceEventStartTime")
ModifyInstanceEventWindow = Action("ModifyInstanceEventWindow")
ModifyInstanceMaintenanceOptions = Action("ModifyInstanceMaintenanceOptions")
ModifyInstanceMetadataOptions = Action("ModifyInstanceMetadataOptions")
ModifyInstancePlacement = Action("ModifyInstancePlacement")
ModifyIpam = Action("ModifyIpam")
ModifyIpamPool = Action("ModifyIpamPool")
ModifyIpamResourceCidr = Action("ModifyIpamResourceCidr")
ModifyIpamScope = Action("ModifyIpamScope")
ModifyLaunchTemplate = Action("ModifyLaunchTemplate")
ModifyManagedPrefixList = Action("ModifyManagedPrefixList")
ModifyNetworkInterfaceAttribute = Action("ModifyNetworkInterfaceAttribute")
ModifyPrivateDnsNameOptions = Action("ModifyPrivateDnsNameOptions")
ModifyReservedInstances = Action("ModifyReservedInstances")
ModifySecurityGroupRules = Action("ModifySecurityGroupRules")
ModifySnapshotAttribute = Action("ModifySnapshotAttribute")
ModifySnapshotTier = Action("ModifySnapshotTier")
ModifySpotFleetRequest = Action("ModifySpotFleetRequest")
ModifySubnetAttribute = Action("ModifySubnetAttribute")
ModifyTrafficMirrorFilterNetworkServices = Action(
    "ModifyTrafficMirrorFilterNetworkServices"
)
ModifyTrafficMirrorFilterRule = Action("ModifyTrafficMirrorFilterRule")
ModifyTrafficMirrorSession = Action("ModifyTrafficMirrorSession")
ModifyTransitGateway = Action("ModifyTransitGateway")
ModifyTransitGatewayPrefixListReference = Action(
    "ModifyTransitGatewayPrefixListReference"
)
ModifyTransitGatewayVpcAttachment = Action("ModifyTransitGatewayVpcAttachment")
ModifyVolume = Action("ModifyVolume")
ModifyVolumeAttribute = Action("ModifyVolumeAttribute")
ModifyVpcAttribute = Action("ModifyVpcAttribute")
ModifyVpcEndpoint = Action("ModifyVpcEndpoint")
ModifyVpcEndpointConnectionNotification = Action(
    "ModifyVpcEndpointConnectionNotification"
)
ModifyVpcEndpointServiceConfiguration = Action("ModifyVpcEndpointServiceConfiguration")
ModifyVpcEndpointServicePayerResponsibility = Action(
    "ModifyVpcEndpointServicePayerResponsibility"
)
ModifyVpcEndpointServicePermissions = Action("ModifyVpcEndpointServicePermissions")
ModifyVpcPeeringConnectionOptions = Action("ModifyVpcPeeringConnectionOptions")
ModifyVpcTenancy = Action("ModifyVpcTenancy")
ModifyVpnConnection = Action("ModifyVpnConnection")
ModifyVpnConnectionOptions = Action("ModifyVpnConnectionOptions")
ModifyVpnTunnelCertificate = Action("ModifyVpnTunnelCertificate")
ModifyVpnTunnelOptions = Action("ModifyVpnTunnelOptions")
MonitorInstances = Action("MonitorInstances")
MoveAddressToVpc = Action("MoveAddressToVpc")
MoveByoipCidrToIpam = Action("MoveByoipCidrToIpam")
ProvisionByoipCidr = Action("ProvisionByoipCidr")
ProvisionIpamPoolCidr = Action("ProvisionIpamPoolCidr")
ProvisionPublicIpv4PoolCidr = Action("ProvisionPublicIpv4PoolCidr")
PurchaseHostReservation = Action("PurchaseHostReservation")
PurchaseReservedInstancesOffering = Action("PurchaseReservedInstancesOffering")
PurchaseScheduledInstances = Action("PurchaseScheduledInstances")
PutResourcePolicy = Action("PutResourcePolicy")
RebootInstances = Action("RebootInstances")
RegisterImage = Action("RegisterImage")
RegisterInstanceEventNotificationAttributes = Action(
    "RegisterInstanceEventNotificationAttributes"
)
RegisterTransitGatewayMulticastGroupMembers = Action(
    "RegisterTransitGatewayMulticastGroupMembers"
)
RegisterTransitGatewayMulticastGroupSources = Action(
    "RegisterTransitGatewayMulticastGroupSources"
)
RejectTransitGatewayMulticastDomainAssociations = Action(
    "RejectTransitGatewayMulticastDomainAssociations"
)
RejectTransitGatewayPeeringAttachment = Action("RejectTransitGatewayPeeringAttachment")
RejectTransitGatewayVpcAttachment = Action("RejectTransitGatewayVpcAttachment")
RejectVpcEndpointConnections = Action("RejectVpcEndpointConnections")
RejectVpcPeeringConnection = Action("RejectVpcPeeringConnection")
ReleaseAddress = Action("ReleaseAddress")
ReleaseHosts = Action("ReleaseHosts")
ReleaseIpamPoolAllocation = Action("ReleaseIpamPoolAllocation")
ReplaceIamInstanceProfileAssociation = Action("ReplaceIamInstanceProfileAssociation")
ReplaceNetworkAclAssociation = Action("ReplaceNetworkAclAssociation")
ReplaceNetworkAclEntry = Action("ReplaceNetworkAclEntry")
ReplaceRoute = Action("ReplaceRoute")
ReplaceRouteTableAssociation = Action("ReplaceRouteTableAssociation")
ReplaceTransitGatewayRoute = Action("ReplaceTransitGatewayRoute")
ReportInstanceStatus = Action("ReportInstanceStatus")
RequestSpotFleet = Action("RequestSpotFleet")
RequestSpotInstances = Action("RequestSpotInstances")
ResetAddressAttribute = Action("ResetAddressAttribute")
ResetEbsDefaultKmsKeyId = Action("ResetEbsDefaultKmsKeyId")
ResetFpgaImageAttribute = Action("ResetFpgaImageAttribute")
ResetImageAttribute = Action("ResetImageAttribute")
ResetInstanceAttribute = Action("ResetInstanceAttribute")
ResetNetworkInterfaceAttribute = Action("ResetNetworkInterfaceAttribute")
ResetSnapshotAttribute = Action("ResetSnapshotAttribute")
RestoreAddressToClassic = Action("RestoreAddressToClassic")
RestoreImageFromRecycleBin = Action("RestoreImageFromRecycleBin")
RestoreManagedPrefixListVersion = Action("RestoreManagedPrefixListVersion")
RestoreSnapshotFromRecycleBin = Action("RestoreSnapshotFromRecycleBin")
RestoreSnapshotTier = Action("RestoreSnapshotTier")
RevokeClientVpnIngress = Action("RevokeClientVpnIngress")
RevokeSecurityGroupEgress = Action("RevokeSecurityGroupEgress")
RevokeSecurityGroupIngress = Action("RevokeSecurityGroupIngress")
RunInstances = Action("RunInstances")
RunScheduledInstances = Action("RunScheduledInstances")
SearchLocalGatewayRoutes = Action("SearchLocalGatewayRoutes")
SearchTransitGatewayMulticastGroups = Action("SearchTransitGatewayMulticastGroups")
SearchTransitGatewayRoutes = Action("SearchTransitGatewayRoutes")
SendDiagnosticInterrupt = Action("SendDiagnosticInterrupt")
SendSpotInstanceInterruptions = Action("SendSpotInstanceInterruptions")
StartInstances = Action("StartInstances")
StartNetworkInsightsAccessScopeAnalysis = Action(
    "StartNetworkInsightsAccessScopeAnalysis"
)
StartNetworkInsightsAnalysis = Action("StartNetworkInsightsAnalysis")
StartVpcEndpointServicePrivateDnsVerification = Action(
    "StartVpcEndpointServicePrivateDnsVerification"
)
StopInstances = Action("StopInstances")
TerminateClientVpnConnections = Action("TerminateClientVpnConnections")
TerminateInstances = Action("TerminateInstances")
UnassignIpv6Addresses = Action("UnassignIpv6Addresses")
UnassignPrivateIpAddresses = Action("UnassignPrivateIpAddresses")
UnmonitorInstances = Action("UnmonitorInstances")
UpdateSecurityGroupRuleDescriptionsEgress = Action(
    "UpdateSecurityGroupRuleDescriptionsEgress"
)
UpdateSecurityGroupRuleDescriptionsIngress = Action(
    "UpdateSecurityGroupRuleDescriptionsIngress"
)
WithdrawByoipCidr = Action("WithdrawByoipCidr")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "Amazon Elastic Kubernetes Service"
prefix = "eks"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


AccessKubernetesApi = Action("AccessKubernetesApi")
AssociateEncryptionConfig = Action("AssociateEncryptionConfig")
AssociateIdentityProviderConfig = Action("AssociateIdentityProviderConfig")
CreateAddon = Action("CreateAddon")
CreateCluster = Action("CreateCluster")
CreateFargateProfile = Action("CreateFargateProfile")
CreateNodegroup = Action("CreateNodegroup")
DeleteAddon = Action("DeleteAddon")
DeleteCluster = Action("DeleteCluster")
DeleteFargateProfile = Action("DeleteFargateProfile")
DeleteNodegroup = Action("DeleteNodegroup")
DeregisterCluster = Action("DeregisterCluster")
DescribeAddon = Action("DescribeAddon")
DescribeAddonVersions = Action("DescribeAddonVersions")
DescribeCluster = Action("DescribeCluster")
DescribeFargateProfile = Action("DescribeFargateProfile")
DescribeIdentityProviderConfig = Action("DescribeIdentityProviderConfig")
DescribeNodegroup = Action("DescribeNodegroup")
DescribeUpdate = Action("DescribeUpdate")
DisassociateIdentityProviderConfig = Action("DisassociateIdentityProviderConfig")
ListAddons = Action("ListAddons")
ListClusters = Action("ListClusters")
ListFargateProfiles = Action("ListFargateProfiles")
ListIdentityProviderConfigs = Action("ListIdentityProviderConfigs")
ListNodegroups = Action("ListNodegroups")
ListTagsForResource = Action("ListTagsForResource")
ListUpdates = Action("ListUpdates")
RegisterCluster = Action("RegisterCluster")
TagResource = Action("TagResource")
UntagResource = Action("UntagResource")
UpdateAddon = Action("UpdateAddon")
UpdateClusterConfig = Action("UpdateClusterConfig")
UpdateClusterVersion = Action("UpdateClusterVersion")
UpdateNodegroupConfig = Action("UpdateNodegroupConfig")
UpdateNodegroupVersion = Action("UpdateNodegroupVersion")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "AWS Compute Optimizer"
prefix = "compute-optimizer"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


DeleteRecommendationPreferences = Action("DeleteRecommendationPreferences")
DescribeRecommendationExportJobs = Action("DescribeRecommendationExportJobs")
ExportAutoScalingGroupRecommendations = Action("ExportAutoScalingGroupRecommendations")
ExportEBSVolumeRecommendations = Action("ExportEBSVolumeRecommendations")
ExportEC2InstanceRecommendations = Action("ExportEC2InstanceRecommendations")
ExportLambdaFunctionRecommendations = Action("ExportLambdaFunctionRecommendations")
GetAutoScalingGroupRecommendations = Action("GetAutoScalingGroupRecommendations")
GetEBSVolumeRecommendations = Action("GetEBSVolumeRecommendations")
GetEC2InstanceRecommendations = Action("GetEC2InstanceRecommendations")
GetEC2RecommendationProjectedMetrics = Action("GetEC2RecommendationProjectedMetrics")
GetEffectiveRecommendationPreferences = Action("GetEffectiveRecommendationPreferences")
GetEnrollmentStatus = Action("GetEnrollmentStatus")
GetEnrollmentStatusesForOrganization = Action("GetEnrollmentStatusesForOrganization")
GetLambdaFunctionRecommendations = Action("GetLambdaFunctionRecommendations")
GetRecommendationPreferences = Action("GetRecommendationPreferences")
GetRecommendationSummaries = Action("GetRecommendationSummaries")
PutRecommendationPreferences = Action("PutRecommendationPreferences")
UpdateEnrollmentStatus = Action("UpdateEnrollmentStatus")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "Amazon Elastic Container Registry"
prefix = "ecr"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


BatchCheckLayerAvailability = Action("BatchCheckLayerAvailability")
BatchDeleteImage = Action("BatchDeleteImage")
BatchGetImage = Action("BatchGetImage")
BatchGetRepositoryScanningConfiguration = Action(
    "BatchGetRepositoryScanningConfiguration"
)
BatchImportUpstreamImage = Action("BatchImportUpstreamImage")
CompleteLayerUpload = Action("CompleteLayerUpload")
CreatePullThroughCacheRule = Action("CreatePullThroughCacheRule")
CreateRepository = Action("CreateRepository")
DeleteLifecyclePolicy = Action("DeleteLifecyclePolicy")
DeletePullThroughCacheRule = Action("DeletePullThroughCacheRule")
DeleteRegistryPolicy = Action("DeleteRegistryPolicy")
DeleteRepository = Action("DeleteRepository")
DeleteRepositoryPolicy = Action("DeleteRepositoryPolicy")
DescribeImageReplicationStatus = Action("DescribeImageReplicationStatus")
DescribeImageScanFindings = Action("DescribeImageScanFindings")
DescribeImages = Action("DescribeImages")
DescribePullThroughCacheRules = Action("DescribePullThroughCacheRules")
DescribeRegistry = Action("DescribeRegistry")
DescribeRepositories = Action("DescribeRepositories")
GetAuthorizationToken = Action("GetAuthorizationToken")
GetDownloadUrlForLayer = Action("GetDownloadUrlForLayer")
GetLifecyclePolicy = Action("GetLifecyclePolicy")
GetLifecyclePolicyPreview = Action("GetLifecyclePolicyPreview")
GetRegistryPolicy = Action("GetRegistryPolicy")
GetRegistryScanningConfiguration = Action("GetRegistryScanningConfiguration")
GetRepositoryPolicy = Action("GetRepositoryPolicy")
InitiateLayerUpload = Action("InitiateLayerUpload")
ListImages = Action("ListImages")
ListTagsForResource = Action("ListTagsForResource")
PutImage = Action("PutImage")
PutImageScanningConfiguration = Action("PutImageScanningConfiguration")
PutImageTagMutability = Action("PutImageTagMutability")
PutLifecyclePolicy = Action("PutLifecyclePolicy")
PutRegistryPolicy = Action("PutRegistryPolicy")
PutRegistryScanningConfiguration = Action("PutRegistryScanningConfiguration")
PutReplicationConfiguration = Action("PutReplicationConfiguration")
ReplicateImage = Action("ReplicateImage")
SetRepositoryPolicy = Action("SetRepositoryPolicy")
StartImageScan = Action("StartImageScan")
StartLifecyclePolicyPreview = Action("StartLifecyclePolicyPreview")
TagResource = Action("TagResource")
UntagResource = Action("UntagResource")
UploadLayerPart = Action("UploadLayerPart")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "Amazon EventBridge Schemas"
prefix = "schemas"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


CreateDiscoverer = Action("CreateDiscoverer")
CreateRegistry = Action("CreateRegistry")
CreateSchema = Action("CreateSchema")
DeleteDiscoverer = Action("DeleteDiscoverer")
DeleteRegistry = Action("DeleteRegistry")
DeleteResourcePolicy = Action("DeleteResourcePolicy")
DeleteSchema = Action("DeleteSchema")
DeleteSchemaVersion = Action("DeleteSchemaVersion")
DescribeCodeBinding = Action("DescribeCodeBinding")
DescribeDiscoverer = Action("DescribeDiscoverer")
DescribeRegistry = Action("DescribeRegistry")
DescribeSchema = Action("DescribeSchema")
ExportSchema = Action("ExportSchema")
GetCodeBindingSource = Action("GetCodeBindingSource")
GetDiscoveredSchema = Action("GetDiscoveredSchema")
GetResourcePolicy = Action("GetResourcePolicy")
ListDiscoverers = Action("ListDiscoverers")
ListRegistries = Action("ListRegistries")
ListSchemaVersions = Action("ListSchemaVersions")
ListSchemas = Action("ListSchemas")
ListTagsForResource = Action("ListTagsForResource")
PutCodeBinding = Action("PutCodeBinding")
PutResourcePolicy = Action("PutResourcePolicy")
SearchSchemas = Action("SearchSchemas")
StartDiscoverer = Action("StartDiscoverer")
StopDiscoverer = Action("StopDiscoverer")
TagResource = Action("TagResource")
UntagResource = Action("UntagResource")
UpdateDiscoverer = Action("UpdateDiscoverer")
UpdateRegistry = Action("UpdateRegistry")
UpdateSchema = Action("UpdateSchema")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "Amazon Pinpoint SMS and Voice Service"
prefix = "sms-voice"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


AssociateOriginationIdentity = Action("AssociateOriginationIdentity")
CreateConfigurationSet = Action("CreateConfigurationSet")
CreateConfigurationSetEventDestination = Action(
    "CreateConfigurationSetEventDestination"
)
CreateEventDestination = Action("CreateEventDestination")
CreateOptOutList = Action("CreateOptOutList")
CreatePool = Action("CreatePool")
DeleteConfigurationSet = Action("DeleteConfigurationSet")
DeleteConfigurationSetEventDestination = Action(
    "DeleteConfigurationSetEventDestination"
)
DeleteDefaultMessageType = Action("DeleteDefaultMessageType")
DeleteDefaultSenderId = Action("DeleteDefaultSenderId")
DeleteEventDestination = Action("DeleteEventDestination")
DeleteKeyword = Action("DeleteKeyword")
DeleteOptOutList = Action("DeleteOptOutList")
DeleteOptedOutNumber = Action("DeleteOptedOutNumber")
DeletePool = Action("DeletePool")
DeleteTextMessageSpendLimitOverride = Action("DeleteTextMessageSpendLimitOverride")
DeleteVoiceMessageSpendLimitOverride = Action("DeleteVoiceMessageSpendLimitOverride")
DescribeAccountAttributes = Action("DescribeAccountAttributes")
DescribeAccountLimits = Action("DescribeAccountLimits")
DescribeConfigurationSets = Action("DescribeConfigurationSets")
DescribeKeywords = Action("DescribeKeywords")
DescribeOptOutLists = Action("DescribeOptOutLists")
DescribeOptedOutNumbers = Action("DescribeOptedOutNumbers")
DescribePhoneNumbers = Action("DescribePhoneNumbers")
DescribePools = Action("DescribePools")
DescribeSenderIds = Action("DescribeSenderIds")
DescribeSpendLimits = Action("DescribeSpendLimits")
DisassociateOriginationIdentity = Action("DisassociateOriginationIdentity")
GetConfigurationSetEventDestinations = Action("GetConfigurationSetEventDestinations")
ListConfigurationSets = Action("ListConfigurationSets")
ListPoolOriginationIdentities = Action("ListPoolOriginationIdentities")
ListTagsForResource = Action("ListTagsForResource")
PutKeyword = Action("PutKeyword")
PutOptedOutNumber = Action("PutOptedOutNumber")
ReleasePhoneNumber = Action("ReleasePhoneNumber")
RequestPhoneNumber = Action("RequestPhoneNumber")
SendTextMessage = Action("SendTextMessage")
SendVoiceMessage = Action("SendVoiceMessage")
SetDefaultMessageType = Action("SetDefaultMessageType")
SetDefaultSenderId = Action("SetDefaultSenderId")
SetTextMessageSpendLimitOverride = Action("SetTextMessageSpendLimitOverride")
SetVoiceMessageSpendLimitOverride = Action("SetVoiceMessageSpendLimitOverride")
TagResource = Action("TagResource")
UntagResource = Action("UntagResource")
UpdateConfigurationSetEventDestination = Action(
    "UpdateConfigurationSetEventDestination"
)
UpdateEventDestination = Action("UpdateEventDestination")
UpdatePhoneNumber = Action("UpdatePhoneNumber")
UpdatePool = Action("UpdatePool")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "AWS DataSync"
prefix = "datasync"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


CancelTaskExecution = Action("CancelTaskExecution")
CreateAgent = Action("CreateAgent")
CreateLocationEfs = Action("CreateLocationEfs")
CreateLocationFsxLustre = Action("CreateLocationFsxLustre")
CreateLocationFsxOpenZfs = Action("CreateLocationFsxOpenZfs")
CreateLocationFsxWindows = Action("CreateLocationFsxWindows")
CreateLocationHdfs = Action("CreateLocationHdfs")
CreateLocationNfs = Action("CreateLocationNfs")
CreateLocationObjectStorage = Action("CreateLocationObjectStorage")
CreateLocationS3 = Action("CreateLocationS3")
CreateLocationSmb = Action("CreateLocationSmb")
CreateTask = Action("CreateTask")
DeleteAgent = Action("DeleteAgent")
DeleteLocation = Action("DeleteLocation")
DeleteTask = Action("DeleteTask")
DescribeAgent = Action("DescribeAgent")
DescribeLocationEfs = Action("DescribeLocationEfs")
DescribeLocationFsxLustre = Action("DescribeLocationFsxLustre")
DescribeLocationFsxOpenZfs = Action("DescribeLocationFsxOpenZfs")
DescribeLocationFsxWindows = Action("DescribeLocationFsxWindows")
DescribeLocationHdfs = Action("DescribeLocationHdfs")
DescribeLocationNfs = Action("DescribeLocationNfs")
DescribeLocationObjectStorage = Action("DescribeLocationObjectStorage")
DescribeLocationS3 = Action("DescribeLocationS3")
DescribeLocationSmb = Action("DescribeLocationSmb")
DescribeTask = Action("DescribeTask")
DescribeTaskExecution = Action("DescribeTaskExecution")
ListAgents = Action("ListAgents")
ListLocations = Action("ListLocations")
ListTagsForResource = Action("ListTagsForResource")
ListTaskExecutions = Action("ListTaskExecutions")
ListTasks = Action("ListTasks")
StartTaskExecution = Action("StartTaskExecution")
TagResource = Action("TagResource")
UntagResource = Action("UntagResource")
UpdateAgent = Action("UpdateAgent")
UpdateLocationHdfs = Action("UpdateLocationHdfs")
UpdateLocationNfs = Action("UpdateLocationNfs")
UpdateLocationObjectStorage = Action("UpdateLocationObjectStorage")
UpdateLocationSmb = Action("UpdateLocationSmb")
UpdateTask = Action("UpdateTask")
UpdateTaskExecution = Action("UpdateTaskExecution")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "Amazon CloudFront"
prefix = "cloudfront"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


AssociateAlias = Action("AssociateAlias")
CreateCachePolicy = Action("CreateCachePolicy")
CreateCloudFrontOriginAccessIdentity = Action("CreateCloudFrontOriginAccessIdentity")
CreateDistribution = Action("CreateDistribution")
CreateDistributionWithTags = Action("CreateDistributionWithTags")
CreateFieldLevelEncryptionConfig = Action("CreateFieldLevelEncryptionConfig")
CreateFieldLevelEncryptionProfile = Action("CreateFieldLevelEncryptionProfile")
CreateFunction = Action("CreateFunction")
CreateInvalidation = Action("CreateInvalidation")
CreateKeyGroup = Action("CreateKeyGroup")
CreateMonitoringSubscription = Action("CreateMonitoringSubscription")
CreateOriginRequestPolicy = Action("CreateOriginRequestPolicy")
CreatePublicKey = Action("CreatePublicKey")
CreateRealtimeLogConfig = Action("CreateRealtimeLogConfig")
CreateResponseHeadersPolicy = Action("CreateResponseHeadersPolicy")
CreateStreamingDistribution = Action("CreateStreamingDistribution")
CreateStreamingDistributionWithTags = Action("CreateStreamingDistributionWithTags")
DeleteCachePolicy = Action("DeleteCachePolicy")
DeleteCloudFrontOriginAccessIdentity = Action("DeleteCloudFrontOriginAccessIdentity")
DeleteDistribution = Action("DeleteDistribution")
DeleteFieldLevelEncryptionConfig = Action("DeleteFieldLevelEncryptionConfig")
DeleteFieldLevelEncryptionProfile = Action("DeleteFieldLevelEncryptionProfile")
DeleteFunction = Action("DeleteFunction")
DeleteKeyGroup = Action("DeleteKeyGroup")
DeleteMonitoringSubscription = Action("DeleteMonitoringSubscription")
DeleteOriginRequestPolicy = Action("DeleteOriginRequestPolicy")
DeletePublicKey = Action("DeletePublicKey")
DeleteRealtimeLogConfig = Action("DeleteRealtimeLogConfig")
DeleteResponseHeadersPolicy = Action("DeleteResponseHeadersPolicy")
DeleteStreamingDistribution = Action("DeleteStreamingDistribution")
DescribeFunction = Action("DescribeFunction")
GetCachePolicy = Action("GetCachePolicy")
GetCachePolicyConfig = Action("GetCachePolicyConfig")
GetCloudFrontOriginAccessIdentity = Action("GetCloudFrontOriginAccessIdentity")
GetCloudFrontOriginAccessIdentityConfig = Action(
    "GetCloudFrontOriginAccessIdentityConfig"
)
GetDistribution = Action("GetDistribution")
GetDistributionConfig = Action("GetDistributionConfig")
GetFieldLevelEncryption = Action("GetFieldLevelEncryption")
GetFieldLevelEncryptionConfig = Action("GetFieldLevelEncryptionConfig")
GetFieldLevelEncryptionProfile = Action("GetFieldLevelEncryptionProfile")
GetFieldLevelEncryptionProfileConfig = Action("GetFieldLevelEncryptionProfileConfig")
GetFunction = Action("GetFunction")
GetInvalidation = Action("GetInvalidation")
GetKeyGroup = Action("GetKeyGroup")
GetKeyGroupConfig = Action("GetKeyGroupConfig")
GetMonitoringSubscription = Action("GetMonitoringSubscription")
GetOriginRequestPolicy = Action("GetOriginRequestPolicy")
GetOriginRequestPolicyConfig = Action("GetOriginRequestPolicyConfig")
GetPublicKey = Action("GetPublicKey")
GetPublicKeyConfig = Action("GetPublicKeyConfig")
GetRealtimeLogConfig = Action("GetRealtimeLogConfig")
GetResponseHeadersPolicy = Action("GetResponseHeadersPolicy")
GetResponseHeadersPolicyConfig = Action("GetResponseHeadersPolicyConfig")
GetStreamingDistribution = Action("GetStreamingDistribution")
GetStreamingDistributionConfig = Action("GetStreamingDistributionConfig")
ListCachePolicies = Action("ListCachePolicies")
ListCloudFrontOriginAccessIdentities = Action("ListCloudFrontOriginAccessIdentities")
ListConflictingAliases = Action("ListConflictingAliases")
ListDistributions = Action("ListDistributions")
ListDistributionsByCachePolicyId = Action("ListDistributionsByCachePolicyId")
ListDistributionsByKeyGroup = Action("ListDistributionsByKeyGroup")
ListDistributionsByLambdaFunction = Action("ListDistributionsByLambdaFunction")
ListDistributionsByOriginRequestPolicyId = Action(
    "ListDistributionsByOriginRequestPolicyId"
)
ListDistributionsByRealtimeLogConfig = Action("ListDistributionsByRealtimeLogConfig")
ListDistributionsByResponseHeadersPolicyId = Action(
    "ListDistributionsByResponseHeadersPolicyId"
)
ListDistributionsByWebACLId = Action("ListDistributionsByWebACLId")
ListFieldLevelEncryptionConfigs = Action("ListFieldLevelEncryptionConfigs")
ListFieldLevelEncryptionProfiles = Action("ListFieldLevelEncryptionProfiles")
ListFunctions = Action("ListFunctions")
ListInvalidations = Action("ListInvalidations")
ListKeyGroups = Action("ListKeyGroups")
ListOriginRequestPolicies = Action("ListOriginRequestPolicies")
ListPublicKeys = Action("ListPublicKeys")
ListRealtimeLogConfigs = Action("ListRealtimeLogConfigs")
ListResponseHeadersPolicies = Action("ListResponseHeadersPolicies")
ListStreamingDistributions = Action("ListStreamingDistributions")
ListTagsForResource = Action("ListTagsForResource")
PublishFunction = Action("PublishFunction")
TagResource = Action("TagResource")
TestFunction = Action("TestFunction")
UntagResource = Action("UntagResource")
UpdateCachePolicy = Action("UpdateCachePolicy")
UpdateCloudFrontOriginAccessIdentity = Action("UpdateCloudFrontOriginAccessIdentity")
UpdateDistribution = Action("UpdateDistribution")
UpdateFieldLevelEncryptionConfig = Action("UpdateFieldLevelEncryptionConfig")
UpdateFieldLevelEncryptionProfile = Action("UpdateFieldLevelEncryptionProfile")
UpdateFunction = Action("UpdateFunction")
UpdateKeyGroup = Action("UpdateKeyGroup")
UpdateOriginRequestPolicy = Action("UpdateOriginRequestPolicy")
UpdatePublicKey = Action("UpdatePublicKey")
UpdateRealtimeLogConfig = Action("UpdateRealtimeLogConfig")
UpdateResponseHeadersPolicy = Action("UpdateResponseHeadersPolicy")
UpdateStreamingDistribution = Action("UpdateStreamingDistribution")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "Amazon Kinesis Firehose"
prefix = "firehose"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


CreateDeliveryStream = Action("CreateDeliveryStream")
DeleteDeliveryStream = Action("DeleteDeliveryStream")
DescribeDeliveryStream = Action("DescribeDeliveryStream")
ListDeliveryStreams = Action("ListDeliveryStreams")
ListTagsForDeliveryStream = Action("ListTagsForDeliveryStream")
PutRecord = Action("PutRecord")
PutRecordBatch = Action("PutRecordBatch")
StartDeliveryStreamEncryption = Action("StartDeliveryStreamEncryption")
StopDeliveryStreamEncryption = Action("StopDeliveryStreamEncryption")
TagDeliveryStream = Action("TagDeliveryStream")
UntagDeliveryStream = Action("UntagDeliveryStream")
UpdateDestination = Action("UpdateDestination")
